"""Generated message classes for netapp version v1alpha1.

"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding
from apitools.base.py import extra_types


package = 'netapp'


class ActiveDirectory(_messages.Message):
  r"""ActiveDirectory is the public representation of the active directory
  config.

  Enums:
    StateValueValuesEnum: Output only. The state of the AD.

  Messages:
    LabelsValue: Labels for the active directory.

  Fields:
    aesEncryption: If enabled, AES encryption will be enabled for SMB
      communication.
    backupOperators: Users to be added to the Built-in Backup Operator active
      directory group.
    createTime: Output only. Create time of the active directory.
    description: Description of the active directory.
    dns: Required. Comma separated list of DNS server IP addresses for the
      Active Directory domain.
    domain: Required. Name of the Active Directory domain
    encryptDcConnections: If enabled, traffic between the SMB server to Domain
      Controller (DC) will be encrypted.
    kdcHostname: Name of the active directory machine. This optional parameter
      is used only while creating kerberos volume
    kdcIp: KDC server IP address for the active directory machine.
    labels: Labels for the active directory.
    ldapSigning: Specifies whether or not the LDAP traffic needs to be signed.
    name: Output only. The resource name of the active directory. Format: `pro
      jects/{project_number}/locations/{location_id}/activeDirectories/{active
      _directory_id}`.
    netBiosPrefix: Required. NetBIOSPrefix is used as a prefix for SMB server
      name.
    nfsUsersWithLdap: If enabled, will allow access to local users and LDAP
      users. If access is needed for only LDAP users, it has to be disabled.
    organizationalUnit: The Organizational Unit (OU) within the Windows Active
      Directory the user belongs to.
    password: Required. Password of the Active Directory domain administrator.
    securityOperators: Domain users to be given the SeSecurityPrivilege.
    site: The Active Directory site the service will limit Domain Controller
      discovery too.
    state: Output only. The state of the AD.
    stateDetails: Output only. The state details of the Active Directory.
    username: Required. Username of the Active Directory domain administrator.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. The state of the AD.

    Values:
      STATE_UNSPECIFIED: Unspecified Active Directory State
      CREATING: Active Directory State is Creating
      READY: Active Directory State is Ready
      UPDATING: Active Directory State is Updating
      IN_USE: Active Directory State is In use
      DELETING: Active Directory State is Deleting
      ERROR: Active Directory State is Error
    """
    STATE_UNSPECIFIED = 0
    CREATING = 1
    READY = 2
    UPDATING = 3
    IN_USE = 4
    DELETING = 5
    ERROR = 6

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for the active directory.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  aesEncryption = _messages.BooleanField(1)
  backupOperators = _messages.StringField(2, repeated=True)
  createTime = _messages.StringField(3)
  description = _messages.StringField(4)
  dns = _messages.StringField(5)
  domain = _messages.StringField(6)
  encryptDcConnections = _messages.BooleanField(7)
  kdcHostname = _messages.StringField(8)
  kdcIp = _messages.StringField(9)
  labels = _messages.MessageField('LabelsValue', 10)
  ldapSigning = _messages.BooleanField(11)
  name = _messages.StringField(12)
  netBiosPrefix = _messages.StringField(13)
  nfsUsersWithLdap = _messages.BooleanField(14)
  organizationalUnit = _messages.StringField(15)
  password = _messages.StringField(16)
  securityOperators = _messages.StringField(17, repeated=True)
  site = _messages.StringField(18)
  state = _messages.EnumField('StateValueValuesEnum', 19)
  stateDetails = _messages.StringField(20)
  username = _messages.StringField(21)


class CancelOperationRequest(_messages.Message):
  r"""The request message for Operations.CancelOperation."""


class DailySchedule(_messages.Message):
  r"""Make a snapshot every day e.g. at 04:00, 05:20, 23:50

  Fields:
    hour: Set the hour to start the snapshot (0-23), defaults to midnight (0).
    minute: Set the minute of the hour to start the snapshot (0-59), defaults
      to the top of the hour (0).
    snapshotsToKeep: The maximum number of Snapshots to keep for the hourly
      schedule
  """

  hour = _messages.FloatField(1)
  minute = _messages.FloatField(2)
  snapshotsToKeep = _messages.FloatField(3)


class Empty(_messages.Message):
  r"""A generic empty message that you can re-use to avoid defining duplicated
  empty messages in your APIs. A typical example is to use it as the request
  or the response type of an API method. For instance: service Foo { rpc
  Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
  """



class ExportPolicy(_messages.Message):
  r"""ExportPolicy Defined the export policy for the volume.

  Fields:
    rules: Required. List of export policy rules
  """

  rules = _messages.MessageField('SimpleExportPolicyRule', 1, repeated=True)


class HourlySchedule(_messages.Message):
  r"""Make a snapshot every hour e.g. at 04:00, 05:00, 06:00.

  Fields:
    minute: Set the minute of the hour to start the snapshot (0-59), defaults
      to the top of the hour (0).
    snapshotsToKeep: The maximum number of Snapshots to keep for the hourly
      schedule
  """

  minute = _messages.FloatField(1)
  snapshotsToKeep = _messages.FloatField(2)


class ListActiveDirectoriesResponse(_messages.Message):
  r"""ListActiveDirectoriesResponse contains all the active directories
  requested.

  Fields:
    activeDirectories: The list of active directories.
    nextPageToken: A token identifying a page of results the server should
      return.
    unreachable: Locations that could not be reached.
  """

  activeDirectories = _messages.MessageField('ActiveDirectory', 1, repeated=True)
  nextPageToken = _messages.StringField(2)
  unreachable = _messages.StringField(3, repeated=True)


class ListLocationsResponse(_messages.Message):
  r"""The response message for Locations.ListLocations.

  Fields:
    locations: A list of locations that matches the specified filter in the
      request.
    nextPageToken: The standard List next-page token.
  """

  locations = _messages.MessageField('Location', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class ListOperationsResponse(_messages.Message):
  r"""The response message for Operations.ListOperations.

  Fields:
    nextPageToken: The standard List next-page token.
    operations: A list of operations that matches the specified filter in the
      request.
  """

  nextPageToken = _messages.StringField(1)
  operations = _messages.MessageField('Operation', 2, repeated=True)


class ListSnapshotsResponse(_messages.Message):
  r"""ListSnapshotsResponse is the result of ListSnapshotsRequest.

  Fields:
    nextPageToken: The token you can use to retrieve the next page of results.
      Not returned if there are no more results in the list.
    snapshots: A list of snapshots in the project for the specified volume.
    unreachable: Locations that could not be reached.
  """

  nextPageToken = _messages.StringField(1)
  snapshots = _messages.MessageField('Snapshot', 2, repeated=True)
  unreachable = _messages.StringField(3, repeated=True)


class ListStoragePoolsResponse(_messages.Message):
  r"""ListStoragePoolsResponse

  Fields:
    nextPageToken: A token identifying a page of results the server should
      return.
    storagePools: The list of StoragePools
    unreachable: Locations that could not be reached.
  """

  nextPageToken = _messages.StringField(1)
  storagePools = _messages.MessageField('StoragePool', 2, repeated=True)
  unreachable = _messages.StringField(3, repeated=True)


class ListVolumesResponse(_messages.Message):
  r"""ListVolumesResponse Message for response to listing Volumes

  Fields:
    nextPageToken: A token identifying a page of results the server should
      return.
    unreachable: Locations that could not be reached.
    volumes: The list of Volume
  """

  nextPageToken = _messages.StringField(1)
  unreachable = _messages.StringField(2, repeated=True)
  volumes = _messages.MessageField('Volume', 3, repeated=True)


class Location(_messages.Message):
  r"""A resource that represents Google Cloud Platform location.

  Messages:
    LabelsValue: Cross-service attributes for the location. For example
      {"cloud.googleapis.com/region": "us-east1"}
    MetadataValue: Service-specific metadata. For example the available
      capacity at the given location.

  Fields:
    displayName: The friendly name for this location, typically a nearby city
      name. For example, "Tokyo".
    labels: Cross-service attributes for the location. For example
      {"cloud.googleapis.com/region": "us-east1"}
    locationId: The canonical id for this location. For example: `"us-east1"`.
    metadata: Service-specific metadata. For example the available capacity at
      the given location.
    name: Resource name for the location, which may vary between
      implementations. For example: `"projects/example-project/locations/us-
      east1"`
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Cross-service attributes for the location. For example
    {"cloud.googleapis.com/region": "us-east1"}

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""Service-specific metadata. For example the available capacity at the
    given location.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  displayName = _messages.StringField(1)
  labels = _messages.MessageField('LabelsValue', 2)
  locationId = _messages.StringField(3)
  metadata = _messages.MessageField('MetadataValue', 4)
  name = _messages.StringField(5)


class MonthlySchedule(_messages.Message):
  r"""Make a snapshot once a month e.g. at 2nd 04:00, 7th 05:20, 24th 23:50

  Fields:
    daysOfMonth: Set the day or days of the month to make a snapshot (1-31).
      Accepts a comma separated number of days. Defaults to '1'.
    hour: Set the hour to start the snapshot (0-23), defaults to midnight (0).
    minute: Set the minute of the hour to start the snapshot (0-59), defaults
      to the top of the hour (0).
    snapshotsToKeep: The maximum number of Snapshots to keep for the hourly
      schedule
  """

  daysOfMonth = _messages.StringField(1)
  hour = _messages.FloatField(2)
  minute = _messages.FloatField(3)
  snapshotsToKeep = _messages.FloatField(4)


class MountOption(_messages.Message):
  r"""MountOption View only mount options for a volume.

  Enums:
    ProtocolValueValuesEnum: Protocol to mount with.

  Fields:
    export: Export string
    exportFull: Full export string
    instructions: Instructions for mounting
    protocol: Protocol to mount with.
  """

  class ProtocolValueValuesEnum(_messages.Enum):
    r"""Protocol to mount with.

    Values:
      PROTOCOLS_UNSPECIFIED: Unspecified protocol
      NFSV3: NFS V3 protocol
      NFSV4: NFS V4 protocol
      SMB: SMB protocol
    """
    PROTOCOLS_UNSPECIFIED = 0
    NFSV3 = 1
    NFSV4 = 2
    SMB = 3

  export = _messages.StringField(1)
  exportFull = _messages.StringField(2)
  instructions = _messages.StringField(3)
  protocol = _messages.EnumField('ProtocolValueValuesEnum', 4)


class NetappProjectsLocationsActiveDirectoriesCreateRequest(_messages.Message):
  r"""A NetappProjectsLocationsActiveDirectoriesCreateRequest object.

  Fields:
    activeDirectory: A ActiveDirectory resource to be passed as the request
      body.
    activeDirectoryId: Required. ID of the active directory to create.
    parent: Required. Value for parent.
  """

  activeDirectory = _messages.MessageField('ActiveDirectory', 1)
  activeDirectoryId = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class NetappProjectsLocationsActiveDirectoriesDeleteRequest(_messages.Message):
  r"""A NetappProjectsLocationsActiveDirectoriesDeleteRequest object.

  Fields:
    name: Required. Name of the active directory.
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsActiveDirectoriesGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsActiveDirectoriesGetRequest object.

  Fields:
    name: Required. Name of the active directory.
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsActiveDirectoriesListRequest(_messages.Message):
  r"""A NetappProjectsLocationsActiveDirectoriesListRequest object.

  Fields:
    filter: Filtering results
    orderBy: Hint for how to order the results
    pageSize: Requested page size. Server may return fewer items than
      requested. If unspecified, the server will pick an appropriate default.
    pageToken: A token identifying a page of results the server should return.
    parent: Required. Parent value for ListActiveDirectoriesRequest
  """

  filter = _messages.StringField(1)
  orderBy = _messages.StringField(2)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)
  parent = _messages.StringField(5, required=True)


class NetappProjectsLocationsActiveDirectoriesPatchRequest(_messages.Message):
  r"""A NetappProjectsLocationsActiveDirectoriesPatchRequest object.

  Fields:
    activeDirectory: A ActiveDirectory resource to be passed as the request
      body.
    name: Output only. The resource name of the active directory. Format: `pro
      jects/{project_number}/locations/{location_id}/activeDirectories/{active
      _directory_id}`.
    updateMask: Required. Field mask is used to specify the fields to be
      overwritten in the Active Directory resource by the update. The fields
      specified in the update_mask are relative to the resource, not the full
      request. A field will be overwritten if it is in the mask. If the user
      does not provide a mask then all fields will be overwritten.
  """

  activeDirectory = _messages.MessageField('ActiveDirectory', 1)
  name = _messages.StringField(2, required=True)
  updateMask = _messages.StringField(3)


class NetappProjectsLocationsGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsGetRequest object.

  Fields:
    name: Resource name for the location.
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsListRequest(_messages.Message):
  r"""A NetappProjectsLocationsListRequest object.

  Fields:
    filter: A filter to narrow down results to a preferred subset. The
      filtering language accepts strings like `"displayName=tokyo"`, and is
      documented in more detail in [AIP-160](https://google.aip.dev/160).
    name: The resource that owns the locations collection, if applicable.
    pageSize: The maximum number of results to return. If not set, the service
      selects a default.
    pageToken: A page token received from the `next_page_token` field in the
      response. Send that page token to receive the subsequent page.
  """

  filter = _messages.StringField(1)
  name = _messages.StringField(2, required=True)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)


class NetappProjectsLocationsOperationsCancelRequest(_messages.Message):
  r"""A NetappProjectsLocationsOperationsCancelRequest object.

  Fields:
    cancelOperationRequest: A CancelOperationRequest resource to be passed as
      the request body.
    name: The name of the operation resource to be cancelled.
  """

  cancelOperationRequest = _messages.MessageField('CancelOperationRequest', 1)
  name = _messages.StringField(2, required=True)


class NetappProjectsLocationsOperationsDeleteRequest(_messages.Message):
  r"""A NetappProjectsLocationsOperationsDeleteRequest object.

  Fields:
    name: The name of the operation resource to be deleted.
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsOperationsGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsOperationsGetRequest object.

  Fields:
    name: The name of the operation resource.
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsOperationsListRequest(_messages.Message):
  r"""A NetappProjectsLocationsOperationsListRequest object.

  Fields:
    filter: The standard list filter.
    name: The name of the operation's parent resource.
    pageSize: The standard list page size.
    pageToken: The standard list page token.
  """

  filter = _messages.StringField(1)
  name = _messages.StringField(2, required=True)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)


class NetappProjectsLocationsStoragePoolsCreateRequest(_messages.Message):
  r"""A NetappProjectsLocationsStoragePoolsCreateRequest object.

  Fields:
    parent: Required. Value for parent.
    storagePool: A StoragePool resource to be passed as the request body.
    storagePoolId: Required. Id of the requesting storage pool If auto-
      generating Id server-side, remove this field and id from the
      method_signature of Create RPC
  """

  parent = _messages.StringField(1, required=True)
  storagePool = _messages.MessageField('StoragePool', 2)
  storagePoolId = _messages.StringField(3)


class NetappProjectsLocationsStoragePoolsDeleteRequest(_messages.Message):
  r"""A NetappProjectsLocationsStoragePoolsDeleteRequest object.

  Fields:
    name: Required. Name of the storage pool
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsStoragePoolsGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsStoragePoolsGetRequest object.

  Fields:
    name: Required. Name of the storage pool
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsStoragePoolsListRequest(_messages.Message):
  r"""A NetappProjectsLocationsStoragePoolsListRequest object.

  Fields:
    filter: List filter.
    orderBy: Sort results. Supported values are "name", "name desc" or ""
      (unsorted).
    pageSize: The maximum number of items to return.
    pageToken: The next_page_token value to use if there are additional
      results to retrieve for this list request.
    parent: Required. Parent value
  """

  filter = _messages.StringField(1)
  orderBy = _messages.StringField(2)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)
  parent = _messages.StringField(5, required=True)


class NetappProjectsLocationsStoragePoolsPatchRequest(_messages.Message):
  r"""A NetappProjectsLocationsStoragePoolsPatchRequest object.

  Fields:
    name: Output only. Name of the storage pool
    storagePool: A StoragePool resource to be passed as the request body.
    updateMask: Required. Field mask is used to specify the fields to be
      overwritten in the StoragePool resource by the update. The fields
      specified in the update_mask are relative to the resource, not the full
      request. A field will be overwritten if it is in the mask. If the user
      does not provide a mask then all fields will be overwritten.
  """

  name = _messages.StringField(1, required=True)
  storagePool = _messages.MessageField('StoragePool', 2)
  updateMask = _messages.StringField(3)


class NetappProjectsLocationsVolumesCreateRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesCreateRequest object.

  Fields:
    parent: Required. Value for parent.
    volume: A Volume resource to be passed as the request body.
    volumeId: Required. Id of the requesting volume If auto-generating Id
      server-side, remove this field and Id from the method_signature of
      Create RPC
  """

  parent = _messages.StringField(1, required=True)
  volume = _messages.MessageField('Volume', 2)
  volumeId = _messages.StringField(3)


class NetappProjectsLocationsVolumesDeleteRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesDeleteRequest object.

  Fields:
    force: If this field is set as true, CCFE will not block the volume
      resource deletion even if it has any snapshots resource. (Otherwise, the
      request will only work if the volume has no snapshots.)
    name: Required. Name of the volume
  """

  force = _messages.BooleanField(1)
  name = _messages.StringField(2, required=True)


class NetappProjectsLocationsVolumesGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesGetRequest object.

  Fields:
    name: Required. Name of the volume
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsVolumesListRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesListRequest object.

  Fields:
    filter: Filtering results
    orderBy: Hint for how to order the results
    pageSize: Requested page size. Server may return fewer items than
      requested. If unspecified, the server will pick an appropriate default.
    pageToken: A token identifying a page of results the server should return.
    parent: Required. Parent value for ListVolumesRequest
  """

  filter = _messages.StringField(1)
  orderBy = _messages.StringField(2)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)
  parent = _messages.StringField(5, required=True)


class NetappProjectsLocationsVolumesPatchRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesPatchRequest object.

  Fields:
    name: Output only. Name of the volume
    updateMask: Required. Field mask is used to specify the fields to be
      overwritten in the Volume resource by the update. The fields specified
      in the update_mask are relative to the resource, not the full request. A
      field will be overwritten if it is in the mask. If the user does not
      provide a mask then all fields will be overwritten.
    volume: A Volume resource to be passed as the request body.
  """

  name = _messages.StringField(1, required=True)
  updateMask = _messages.StringField(2)
  volume = _messages.MessageField('Volume', 3)


class NetappProjectsLocationsVolumesRevertRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesRevertRequest object.

  Fields:
    name: Required. The resource name of the volume, in the format of
      projects/{project_id}/locations/{location}/volumes/{volume_id}.
    revertVolumeRequest: A RevertVolumeRequest resource to be passed as the
      request body.
  """

  name = _messages.StringField(1, required=True)
  revertVolumeRequest = _messages.MessageField('RevertVolumeRequest', 2)


class NetappProjectsLocationsVolumesSnapshotsCreateRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesSnapshotsCreateRequest object.

  Fields:
    parent: Required. The NetApp volume to create the snapshots of, in the
      format `projects/{project_id}/locations/{location}/volumes/{volume_id}`
    snapshot: A Snapshot resource to be passed as the request body.
    snapshotId: Required. ID of the snapshot to create. This value must start
      with a lowercase letter followed by up to 62 lowercase letters, numbers,
      or hyphens, and cannot end with a hyphen.
  """

  parent = _messages.StringField(1, required=True)
  snapshot = _messages.MessageField('Snapshot', 2)
  snapshotId = _messages.StringField(3)


class NetappProjectsLocationsVolumesSnapshotsDeleteRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesSnapshotsDeleteRequest object.

  Fields:
    name: Required. The snapshot resource name, in the format
      `projects/*/locations/*/volumes/*/snapshots/{snapshot_id}`
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsVolumesSnapshotsGetRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesSnapshotsGetRequest object.

  Fields:
    name: Required. The snapshot resource name, in the format `projects/{proje
      ct_id}/locations/{location}/volumes/{volume_id}/snapshots/{snapshot_id}`
  """

  name = _messages.StringField(1, required=True)


class NetappProjectsLocationsVolumesSnapshotsListRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesSnapshotsListRequest object.

  Fields:
    filter: List filter.
    orderBy: Sort results. Supported values are "name", "name desc" or ""
      (unsorted).
    pageSize: The maximum number of items to return.
    pageToken: The next_page_token value to use if there are additional
      results to retrieve for this list request.
    parent: Required. The volume for which to retrieve snapshot information,
      in the format
      `projects/{project_id}/locations/{location}/volumes/{volume_id}`.
  """

  filter = _messages.StringField(1)
  orderBy = _messages.StringField(2)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)
  parent = _messages.StringField(5, required=True)


class NetappProjectsLocationsVolumesSnapshotsPatchRequest(_messages.Message):
  r"""A NetappProjectsLocationsVolumesSnapshotsPatchRequest object.

  Fields:
    name: Output only. The resource name of the snapshot. Format: `projects/{p
      roject_id}/locations/{location}/volumes/{volume_id}/snapshots/{snapshot_
      id}`.
    snapshot: A Snapshot resource to be passed as the request body.
    updateMask: Required. Mask of fields to update. At least one path must be
      supplied in this field.
  """

  name = _messages.StringField(1, required=True)
  snapshot = _messages.MessageField('Snapshot', 2)
  updateMask = _messages.StringField(3)


class Operation(_messages.Message):
  r"""This resource represents a long-running operation that is the result of
  a network API call.

  Messages:
    MetadataValue: Service-specific metadata associated with the operation. It
      typically contains progress information and common metadata such as
      create time. Some services might not provide such metadata. Any method
      that returns a long-running operation should document the metadata type,
      if any.
    ResponseValue: The normal response of the operation in case of success. If
      the original method returns no data on success, such as `Delete`, the
      response is `google.protobuf.Empty`. If the original method is standard
      `Get`/`Create`/`Update`, the response should be the resource. For other
      methods, the response should have the type `XxxResponse`, where `Xxx` is
      the original method name. For example, if the original method name is
      `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.

  Fields:
    done: If the value is `false`, it means the operation is still in
      progress. If `true`, the operation is completed, and either `error` or
      `response` is available.
    error: The error result of the operation in case of failure or
      cancellation.
    metadata: Service-specific metadata associated with the operation. It
      typically contains progress information and common metadata such as
      create time. Some services might not provide such metadata. Any method
      that returns a long-running operation should document the metadata type,
      if any.
    name: The server-assigned name, which is only unique within the same
      service that originally returns it. If you use the default HTTP mapping,
      the `name` should be a resource name ending with
      `operations/{unique_id}`.
    response: The normal response of the operation in case of success. If the
      original method returns no data on success, such as `Delete`, the
      response is `google.protobuf.Empty`. If the original method is standard
      `Get`/`Create`/`Update`, the response should be the resource. For other
      methods, the response should have the type `XxxResponse`, where `Xxx` is
      the original method name. For example, if the original method name is
      `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""Service-specific metadata associated with the operation. It typically
    contains progress information and common metadata such as create time.
    Some services might not provide such metadata. Any method that returns a
    long-running operation should document the metadata type, if any.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ResponseValue(_messages.Message):
    r"""The normal response of the operation in case of success. If the
    original method returns no data on success, such as `Delete`, the response
    is `google.protobuf.Empty`. If the original method is standard
    `Get`/`Create`/`Update`, the response should be the resource. For other
    methods, the response should have the type `XxxResponse`, where `Xxx` is
    the original method name. For example, if the original method name is
    `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.

    Messages:
      AdditionalProperty: An additional property for a ResponseValue object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ResponseValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  done = _messages.BooleanField(1)
  error = _messages.MessageField('Status', 2)
  metadata = _messages.MessageField('MetadataValue', 3)
  name = _messages.StringField(4)
  response = _messages.MessageField('ResponseValue', 5)


class OperationMetadata(_messages.Message):
  r"""OperationMetadata Represents the metadata of the long-running operation.

  Fields:
    apiVersion: Output only. API version used to start the operation.
    createTime: Output only. The time the operation was created.
    endTime: Output only. The time the operation finished running.
    requestedCancellation: Output only. Identifies whether the user has
      requested cancellation of the operation. Operations that have been
      canceled successfully have Operation.error value with a
      google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
    statusMessage: Output only. Human-readable status of the operation, if
      any.
    target: Output only. Server-defined resource path for the target of the
      operation.
    verb: Output only. Name of the verb executed by the operation.
  """

  apiVersion = _messages.StringField(1)
  createTime = _messages.StringField(2)
  endTime = _messages.StringField(3)
  requestedCancellation = _messages.BooleanField(4)
  statusMessage = _messages.StringField(5)
  target = _messages.StringField(6)
  verb = _messages.StringField(7)


class RestoreParameters(_messages.Message):
  r"""The RestoreParameters if volume is created from a snapshot or backup.

  Fields:
    sourceSnapshot: Full name of the snapshot resource. Format: projects/{proj
      ect}/locations/{location}/volumes/{volume}/snapshots/{snapshot}
  """

  sourceSnapshot = _messages.StringField(1)


class RevertVolumeRequest(_messages.Message):
  r"""RevertVolumeRequest reverts the given volume to the specified snapshot.

  Fields:
    snapshotId: Required. The snapshot resource ID, in the format 'my-
      snapshot', where the specified ID is the {snapshot_id} of the fully
      qualified name like projects/{project_id}/locations/{location_id}/volume
      s/{volume_id}/snapshots/{snapshot_id}
  """

  snapshotId = _messages.StringField(1)


class SimpleExportPolicyRule(_messages.Message):
  r"""SimpleExportPolicyRule An export policy rule describing various export
  options.

  Enums:
    AccessTypeValueValuesEnum: Access type (ReadWrite, ReadOnly, None)

  Fields:
    accessType: Access type (ReadWrite, ReadOnly, None)
    allowedClients: Comma separated list of allowed clients IP addresses
    hasRootAccess: Whether Unix root access will be granted.
    kerberos5ReadOnly: If enabled (true) the rule defines a read only access
      for clients matching the 'allowedClients' specification. It enables nfs
      clients to mount using 'authentication' kerberos security mode.
    kerberos5ReadWrite: If enabled (true) the rule defines read and write
      access for clients matching the 'allowedClients' specification. It
      enables nfs clients to mount using 'authentication' kerberos security
      mode. The 'kerberos5ReadOnly' value be ignored if this is enabled.
    kerberos5iReadOnly: If enabled (true) the rule defines a read only access
      for clients matching the 'allowedClients' specification. It enables nfs
      clients to mount using 'integrity' kerberos security mode.
    kerberos5iReadWrite: If enabled (true) the rule defines read and write
      access for clients matching the 'allowedClients' specification. It
      enables nfs clients to mount using 'integrity' kerberos security mode.
      The 'kerberos5iReadOnly' value be ignored if this is enabled.
    kerberos5pReadOnly: If enabled (true) the rule defines a read only access
      for clients matching the 'allowedClients' specification. It enables nfs
      clients to mount using 'privacy' kerberos security mode.
    kerberos5pReadWrite: If enabled (true) the rule defines read and write
      access for clients matching the 'allowedClients' specification. It
      enables nfs clients to mount using 'privacy' kerberos security mode. The
      'kerberos5pReadOnly' value be ignored if this is enabled.
    nfsv3: NFS V3 protocol.
    nfsv4: NFS V4 protocol.
  """

  class AccessTypeValueValuesEnum(_messages.Enum):
    r"""Access type (ReadWrite, ReadOnly, None)

    Values:
      ACCESS_TYPE_UNSPECIFIED: Unspecified Access Type
      READ_ONLY: Read Only
      READ_WRITE: Read Write
      READ_NONE: None
    """
    ACCESS_TYPE_UNSPECIFIED = 0
    READ_ONLY = 1
    READ_WRITE = 2
    READ_NONE = 3

  accessType = _messages.EnumField('AccessTypeValueValuesEnum', 1)
  allowedClients = _messages.StringField(2)
  hasRootAccess = _messages.StringField(3)
  kerberos5ReadOnly = _messages.BooleanField(4)
  kerberos5ReadWrite = _messages.BooleanField(5)
  kerberos5iReadOnly = _messages.BooleanField(6)
  kerberos5iReadWrite = _messages.BooleanField(7)
  kerberos5pReadOnly = _messages.BooleanField(8)
  kerberos5pReadWrite = _messages.BooleanField(9)
  nfsv3 = _messages.BooleanField(10)
  nfsv4 = _messages.BooleanField(11)


class Snapshot(_messages.Message):
  r"""Snapshot

  Enums:
    StateValueValuesEnum: Output only. The snapshot state.

  Messages:
    LabelsValue: Resource labels to represent user provided metadata.

  Fields:
    createTime: Output only. The time when the snapshot was created.
    description: A description of the snapshot with 2048 characters or less.
      Requests with longer descriptions will be rejected.
    labels: Resource labels to represent user provided metadata.
    name: Output only. The resource name of the snapshot. Format: `projects/{p
      roject_id}/locations/{location}/volumes/{volume_id}/snapshots/{snapshot_
      id}`.
    state: Output only. The snapshot state.
    stateDetails: Output only. State details of the storage pool
    usedBytes: Output only. Current storage usage for the snapshot in bytes.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. The snapshot state.

    Values:
      STATE_UNSPECIFIED: Unspecified Snapshot State
      READY: Snapshot State is Ready
      CREATING: Snapshot State is Creating
      DELETING: Snapshot State is Deleting
      UPDATING: Snapshot State is Updating
      DISABLED: Snapshot State is Disabled
      ERROR: Snapshot State is Error
    """
    STATE_UNSPECIFIED = 0
    READY = 1
    CREATING = 2
    DELETING = 3
    UPDATING = 4
    DISABLED = 5
    ERROR = 6

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Resource labels to represent user provided metadata.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  createTime = _messages.StringField(1)
  description = _messages.StringField(2)
  labels = _messages.MessageField('LabelsValue', 3)
  name = _messages.StringField(4)
  state = _messages.EnumField('StateValueValuesEnum', 5)
  stateDetails = _messages.StringField(6)
  usedBytes = _messages.FloatField(7)


class SnapshotPolicy(_messages.Message):
  r"""Snapshot Policy for a volume.

  Fields:
    dailySchedule: Daily schedule policy.
    enabled: If enabled, make snapshots automatically according to the
      schedules. Default is false.
    hourlySchedule: Hourly schedule policy.
    monthlySchedule: Monthly schedule policy.
    weeklySchedule: Weekly schedule policy.
  """

  dailySchedule = _messages.MessageField('DailySchedule', 1)
  enabled = _messages.BooleanField(2)
  hourlySchedule = _messages.MessageField('HourlySchedule', 3)
  monthlySchedule = _messages.MessageField('MonthlySchedule', 4)
  weeklySchedule = _messages.MessageField('WeeklySchedule', 5)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    FXgafvValueValuesEnum: V1 error format.
    AltValueValuesEnum: Data format for response.

  Fields:
    f__xgafv: V1 error format.
    access_token: OAuth access token.
    alt: Data format for response.
    callback: JSONP
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: Available to use for quota purposes for server-side
      applications. Can be any arbitrary string assigned to a user, but should
      not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    uploadType: Legacy upload protocol for media (e.g. "media", "multipart").
    upload_protocol: Upload protocol for media (e.g. "raw", "multipart").
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for response.

    Values:
      json: Responses with Content-Type of application/json
      media: Media download with context-dependent Content-Type
      proto: Responses with Content-Type of application/x-protobuf
    """
    json = 0
    media = 1
    proto = 2

  class FXgafvValueValuesEnum(_messages.Enum):
    r"""V1 error format.

    Values:
      _1: v1 error format
      _2: v2 error format
    """
    _1 = 0
    _2 = 1

  f__xgafv = _messages.EnumField('FXgafvValueValuesEnum', 1)
  access_token = _messages.StringField(2)
  alt = _messages.EnumField('AltValueValuesEnum', 3, default='json')
  callback = _messages.StringField(4)
  fields = _messages.StringField(5)
  key = _messages.StringField(6)
  oauth_token = _messages.StringField(7)
  prettyPrint = _messages.BooleanField(8, default=True)
  quotaUser = _messages.StringField(9)
  trace = _messages.StringField(10)
  uploadType = _messages.StringField(11)
  upload_protocol = _messages.StringField(12)


class Status(_messages.Message):
  r"""The `Status` type defines a logical error model that is suitable for
  different programming environments, including REST APIs and RPC APIs. It is
  used by [gRPC](https://github.com/grpc). Each `Status` message contains
  three pieces of data: error code, error message, and error details. You can
  find out more about this error model and how to work with it in the [API
  Design Guide](https://cloud.google.com/apis/design/errors).

  Messages:
    DetailsValueListEntry: A DetailsValueListEntry object.

  Fields:
    code: The status code, which should be an enum value of google.rpc.Code.
    details: A list of messages that carry the error details. There is a
      common set of message types for APIs to use.
    message: A developer-facing error message, which should be in English. Any
      user-facing error message should be localized and sent in the
      google.rpc.Status.details field, or localized by the client.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DetailsValueListEntry(_messages.Message):
    r"""A DetailsValueListEntry object.

    Messages:
      AdditionalProperty: An additional property for a DetailsValueListEntry
        object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DetailsValueListEntry object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  details = _messages.MessageField('DetailsValueListEntry', 2, repeated=True)
  message = _messages.StringField(3)


class StoragePool(_messages.Message):
  r"""Resources StoragePool StoragePool is a container for volumes with a
  service level and capacity. Volumes can be created in a pool of sufficient
  available capacity. StoragePool capacity is what you are billed for.

  Enums:
    ServiceLevelValueValuesEnum: Required. Service level of the storage pool
    StateValueValuesEnum: Output only. State of the storage pool

  Messages:
    LabelsValue: Labels as key value pairs

  Fields:
    capacityGib: Required. Capacity in GIB of the pool
    createTime: Output only. Create time of the storage pool
    description: Description of the storage pool
    labels: Labels as key value pairs
    name: Output only. Name of the storage pool
    serviceLevel: Required. Service level of the storage pool
    state: Output only. State of the storage pool
    stateDetails: Output only. State details of the storage pool
    volumeCapacityGib: Output only. Allocated size of all volumes in GIB in
      the storage pool
    volumeCount: Output only. Volume count of the storage pool
  """

  class ServiceLevelValueValuesEnum(_messages.Enum):
    r"""Required. Service level of the storage pool

    Values:
      SERVICE_LEVEL_UNSPECIFIED: Unspecified service level
      PREMIUM: Premium
      EXTREME: Extreme
    """
    SERVICE_LEVEL_UNSPECIFIED = 0
    PREMIUM = 1
    EXTREME = 2

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. State of the storage pool

    Values:
      STATE_UNSPECIFIED: Unspecified Storage Pool State
      READY: Storage Pool State is Ready
      CREATING: Storage Pool State is Creating
      DELETING: Storage Pool State is Deleting
      UPDATING: Storage Pool State is Updating
      RESTORING: Storage Pool State is Restoring
      DISABLED: Storage Pool State is Disabled
      ERROR: Storage Pool State is Error
    """
    STATE_UNSPECIFIED = 0
    READY = 1
    CREATING = 2
    DELETING = 3
    UPDATING = 4
    RESTORING = 5
    DISABLED = 6
    ERROR = 7

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels as key value pairs

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  capacityGib = _messages.IntegerField(1)
  createTime = _messages.StringField(2)
  description = _messages.StringField(3)
  labels = _messages.MessageField('LabelsValue', 4)
  name = _messages.StringField(5)
  serviceLevel = _messages.EnumField('ServiceLevelValueValuesEnum', 6)
  state = _messages.EnumField('StateValueValuesEnum', 7)
  stateDetails = _messages.StringField(8)
  volumeCapacityGib = _messages.IntegerField(9)
  volumeCount = _messages.IntegerField(10, variant=_messages.Variant.INT32)


class Volume(_messages.Message):
  r"""Volume Volume provides a filesystem that you can mount.

  Enums:
    EncryptionTypeValueValuesEnum: Output only. Specified the current volume
      encryption key source.
    ProtocolsValueListEntryValuesEnum:
    SecurityStyleValueValuesEnum: Optional. Security Style of the Volume
    ServiceLevelValueValuesEnum: Output only. Service level of the volume
    SmbSettingsValueListEntryValuesEnum:
    StateValueValuesEnum: Output only. State of the volume

  Messages:
    LabelsValue: Optional. Labels as key value pairs

  Fields:
    activeDirectory: Optional. Specifies the AD to be used for creating a SMB
      volume. ActiveDirectory name of the volume
    capacityGib: Required. Capacity in GIB of the volume
    createTime: Output only. Create time of the volume
    description: Optional. Description of the volume
    encryptionType: Output only. Specified the current volume encryption key
      source.
    exportPolicy: Optional. Export policy of the volume
    kerberosEnabled: Optional. Flag indicating if the volume is a kerberos
      volume or not, export policy rules control kerberos security modes
      (krb5, krb5i, krb5p).
    kmsConfig: Optional. Specifies the KMS config to be used for volume
      encryption.
    labels: Optional. Labels as key value pairs
    ldapEnabled: Optional. Flag indicating if the volume is NFS LDAP enabled
      or not.
    mountOptions: Output only. Mount options of this volume
    name: Output only. Name of the volume
    network: Required. VPC Network name
    protocols: Required. Protocols required for the volume
    psaRange: Optional. Name of the Private Service Access allocated range.
      This is optional. If not provided, any available range will be chosen.
    restoreParameters: Optional. Specifies the source of the volume to be
      created from.
    securityStyle: Optional. Security Style of the Volume
    serviceLevel: Output only. Service level of the volume
    shareName: Required. Share name of the volume
    smbSettings: Optional. SMB share settings for the volume.
    snapReserve: Optional. Snap_reserve specifies percentage of volume storage
      reserved for snapshot storage. Default is 0 percent.
    snapshotDirectory: Optional. Snapshot_directory if enabled (true) the
      volume will contain a read-only .snapshot directory which provides
      access to each of the volume's snapshots.
    snapshotPolicy: Optional. SnapshotPolicy for a volume.
    state: Output only. State of the volume
    stateDetails: Output only. State details of the volume
    storagePool: Required. StoragePool name of the volume
    unixPermissions: Optional. Default unix style permission (e.g. 777) the
      mount point will be created with. Applicable for NFS protocol types
      only.
    usedGib: Output only. Used capacity in GIB of the volume. This is not
      realtime usage, periodically computed by SDE.
  """

  class EncryptionTypeValueValuesEnum(_messages.Enum):
    r"""Output only. Specified the current volume encryption key source.

    Values:
      ENCRYPTION_TYPE_UNSPECIFIED: The source of encryption key is not
        specified.
      SERVICE_MANAGED: Google managed encryption key.
      CLOUD_KMS: Customer managed encryption key, which is stored in KMS.
    """
    ENCRYPTION_TYPE_UNSPECIFIED = 0
    SERVICE_MANAGED = 1
    CLOUD_KMS = 2

  class ProtocolsValueListEntryValuesEnum(_messages.Enum):
    r"""ProtocolsValueListEntryValuesEnum enum type.

    Values:
      PROTOCOLS_UNSPECIFIED: Unspecified protocol
      NFSV3: NFS V3 protocol
      NFSV4: NFS V4 protocol
      SMB: SMB protocol
    """
    PROTOCOLS_UNSPECIFIED = 0
    NFSV3 = 1
    NFSV4 = 2
    SMB = 3

  class SecurityStyleValueValuesEnum(_messages.Enum):
    r"""Optional. Security Style of the Volume

    Values:
      SECURITY_STYLE_UNSPECIFIED: SecurityStyle is unspecified
      NTFS: SecurityStyle uses NTFS
      UNIX: SecurityStyle uses NTFS
    """
    SECURITY_STYLE_UNSPECIFIED = 0
    NTFS = 1
    UNIX = 2

  class ServiceLevelValueValuesEnum(_messages.Enum):
    r"""Output only. Service level of the volume

    Values:
      SERVICE_LEVEL_UNSPECIFIED: Unspecified service level
      PREMIUM: Premium
      EXTREME: Extreme
    """
    SERVICE_LEVEL_UNSPECIFIED = 0
    PREMIUM = 1
    EXTREME = 2

  class SmbSettingsValueListEntryValuesEnum(_messages.Enum):
    r"""SmbSettingsValueListEntryValuesEnum enum type.

    Values:
      SMB_SETTINGS_UNSPECIFIED: Unspecified default option
      ENCRYPT_DATA: SMB setting encrypt data
      BROWSABLE: SMB setting browsable
      CHANGE_NOTIFY: SMB setting notify change
      NON_BROWSABLE: SMB setting not to notify change
      OPLOCKS: SMB setting oplocks
      SHOW_SNAPSHOT: SMB setting to show snapshots
      SHOW_PREVIOUS_VERSIONS: SMB setting to show previous versions
      ACCESS_BASED_ENUMERATION: SMB setting to access volume based on
        enumerartion
      CONTINUOUSLY_AVAILABLE: Continuously available enumeration
    """
    SMB_SETTINGS_UNSPECIFIED = 0
    ENCRYPT_DATA = 1
    BROWSABLE = 2
    CHANGE_NOTIFY = 3
    NON_BROWSABLE = 4
    OPLOCKS = 5
    SHOW_SNAPSHOT = 6
    SHOW_PREVIOUS_VERSIONS = 7
    ACCESS_BASED_ENUMERATION = 8
    CONTINUOUSLY_AVAILABLE = 9

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. State of the volume

    Values:
      STATE_UNSPECIFIED: Unspecified Volume State
      READY: Volume State is Ready
      CREATING: Volume State is Creating
      DELETING: Volume State is Deleting
      UPDATING: Volume State is Updating
      RESTORING: Volume State is Restoring
      DISABLED: Volume State is Disabled
      ERROR: Volume State is Error
    """
    STATE_UNSPECIFIED = 0
    READY = 1
    CREATING = 2
    DELETING = 3
    UPDATING = 4
    RESTORING = 5
    DISABLED = 6
    ERROR = 7

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Optional. Labels as key value pairs

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  activeDirectory = _messages.StringField(1)
  capacityGib = _messages.IntegerField(2)
  createTime = _messages.StringField(3)
  description = _messages.StringField(4)
  encryptionType = _messages.EnumField('EncryptionTypeValueValuesEnum', 5)
  exportPolicy = _messages.MessageField('ExportPolicy', 6)
  kerberosEnabled = _messages.BooleanField(7)
  kmsConfig = _messages.StringField(8)
  labels = _messages.MessageField('LabelsValue', 9)
  ldapEnabled = _messages.BooleanField(10)
  mountOptions = _messages.MessageField('MountOption', 11, repeated=True)
  name = _messages.StringField(12)
  network = _messages.StringField(13)
  protocols = _messages.EnumField('ProtocolsValueListEntryValuesEnum', 14, repeated=True)
  psaRange = _messages.StringField(15)
  restoreParameters = _messages.MessageField('RestoreParameters', 16)
  securityStyle = _messages.EnumField('SecurityStyleValueValuesEnum', 17)
  serviceLevel = _messages.EnumField('ServiceLevelValueValuesEnum', 18)
  shareName = _messages.StringField(19)
  smbSettings = _messages.EnumField('SmbSettingsValueListEntryValuesEnum', 20, repeated=True)
  snapReserve = _messages.FloatField(21)
  snapshotDirectory = _messages.BooleanField(22)
  snapshotPolicy = _messages.MessageField('SnapshotPolicy', 23)
  state = _messages.EnumField('StateValueValuesEnum', 24)
  stateDetails = _messages.StringField(25)
  storagePool = _messages.StringField(26)
  unixPermissions = _messages.StringField(27)
  usedGib = _messages.IntegerField(28)


class WeeklySchedule(_messages.Message):
  r"""Make a snapshot every week e.g. at Monday 04:00, Wednesday 05:20, Sunday
  23:50

  Fields:
    day: Set the day or days of the week to make a snapshot. Accepts a comma
      separated days of the week. Defaults to 'Sunday'.
    hour: Set the hour to start the snapshot (0-23), defaults to midnight (0).
    minute: Set the minute of the hour to start the snapshot (0-59), defaults
      to the top of the hour (0).
    snapshotsToKeep: The maximum number of Snapshots to keep for the hourly
      schedule
  """

  day = _messages.StringField(1)
  hour = _messages.FloatField(2)
  minute = _messages.FloatField(3)
  snapshotsToKeep = _messages.FloatField(4)


encoding.AddCustomJsonFieldMapping(
    StandardQueryParameters, 'f__xgafv', '$.xgafv')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_1', '1')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_2', '2')



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.bigtable.admin.v2 import bigtable_table_admin_pb2 as google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2
from google.bigtable.admin.v2 import table_pb2 as google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from cloudsdk.google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BigtableTableAdminStub(object):
  """Service for creating, configuring, and deleting Cloud Bigtable tables.


  Provides access to the table schemas only, not the data stored within
  the tables.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateTable = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/CreateTable',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CreateTableRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.FromString,
        )
    self.CreateTableFromSnapshot = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/CreateTableFromSnapshot',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CreateTableFromSnapshotRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.ListTables = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/ListTables',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListTablesRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListTablesResponse.FromString,
        )
    self.GetTable = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/GetTable',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GetTableRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.FromString,
        )
    self.DeleteTable = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/DeleteTable',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DeleteTableRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.ModifyColumnFamilies = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/ModifyColumnFamilies',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ModifyColumnFamiliesRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.FromString,
        )
    self.DropRowRange = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/DropRowRange',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DropRowRangeRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GenerateConsistencyToken = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/GenerateConsistencyToken',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GenerateConsistencyTokenRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GenerateConsistencyTokenResponse.FromString,
        )
    self.CheckConsistency = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/CheckConsistency',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CheckConsistencyRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CheckConsistencyResponse.FromString,
        )
    self.SnapshotTable = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/SnapshotTable',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.SnapshotTableRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.GetSnapshot = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/GetSnapshot',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GetSnapshotRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Snapshot.FromString,
        )
    self.ListSnapshots = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/ListSnapshots',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListSnapshotsRequest.SerializeToString,
        response_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListSnapshotsResponse.FromString,
        )
    self.DeleteSnapshot = channel.unary_unary(
        '/google.bigtable.admin.v2.BigtableTableAdmin/DeleteSnapshot',
        request_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DeleteSnapshotRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class BigtableTableAdminServicer(object):
  """Service for creating, configuring, and deleting Cloud Bigtable tables.


  Provides access to the table schemas only, not the data stored within
  the tables.
  """

  def CreateTable(self, request, context):
    """Creates a new table in the specified instance.
    The table can be created with a full set of initial column families,
    specified in the request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateTableFromSnapshot(self, request, context):
    """Creates a new table from the specified snapshot. The target table must
    not exist. The snapshot and the table must be in the same instance.

    Note: This is a private alpha release of Cloud Bigtable snapshots. This
    feature is not currently available to most Cloud Bigtable customers. This
    feature might be changed in backward-incompatible ways and is not
    recommended for production use. It is not subject to any SLA or deprecation
    policy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListTables(self, request, context):
    """Lists all tables served from a specified instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTable(self, request, context):
    """Gets metadata information about the specified table.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteTable(self, request, context):
    """Permanently deletes a specified table and all of its data.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ModifyColumnFamilies(self, request, context):
    """Performs a series of column family modifications on the specified table.
    Either all or none of the modifications will occur before this method
    returns, but data requests received prior to that point may see a table
    where only some modifications have taken effect.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DropRowRange(self, request, context):
    """Permanently drop/delete a row range from a specified table. The request can
    specify whether to delete all rows in a table, or only those that match a
    particular prefix.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateConsistencyToken(self, request, context):
    """Generates a consistency token for a Table, which can be used in
    CheckConsistency to check whether mutations to the table that finished
    before this call started have been replicated. The tokens will be available
    for 90 days.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CheckConsistency(self, request, context):
    """Checks replication consistency based on a consistency token, that is, if
    replication has caught up based on the conditions specified in the token
    and the check request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SnapshotTable(self, request, context):
    """Creates a new snapshot in the specified cluster from the specified
    source table. The cluster and the table must be in the same instance.

    Note: This is a private alpha release of Cloud Bigtable snapshots. This
    feature is not currently available to most Cloud Bigtable customers. This
    feature might be changed in backward-incompatible ways and is not
    recommended for production use. It is not subject to any SLA or deprecation
    policy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSnapshot(self, request, context):
    """Gets metadata information about the specified snapshot.

    Note: This is a private alpha release of Cloud Bigtable snapshots. This
    feature is not currently available to most Cloud Bigtable customers. This
    feature might be changed in backward-incompatible ways and is not
    recommended for production use. It is not subject to any SLA or deprecation
    policy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListSnapshots(self, request, context):
    """Lists all snapshots associated with the specified cluster.

    Note: This is a private alpha release of Cloud Bigtable snapshots. This
    feature is not currently available to most Cloud Bigtable customers. This
    feature might be changed in backward-incompatible ways and is not
    recommended for production use. It is not subject to any SLA or deprecation
    policy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteSnapshot(self, request, context):
    """Permanently deletes the specified snapshot.

    Note: This is a private alpha release of Cloud Bigtable snapshots. This
    feature is not currently available to most Cloud Bigtable customers. This
    feature might be changed in backward-incompatible ways and is not
    recommended for production use. It is not subject to any SLA or deprecation
    policy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BigtableTableAdminServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateTable': grpc.unary_unary_rpc_method_handler(
          servicer.CreateTable,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CreateTableRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.SerializeToString,
      ),
      'CreateTableFromSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.CreateTableFromSnapshot,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CreateTableFromSnapshotRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'ListTables': grpc.unary_unary_rpc_method_handler(
          servicer.ListTables,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListTablesRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListTablesResponse.SerializeToString,
      ),
      'GetTable': grpc.unary_unary_rpc_method_handler(
          servicer.GetTable,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GetTableRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.SerializeToString,
      ),
      'DeleteTable': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteTable,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DeleteTableRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'ModifyColumnFamilies': grpc.unary_unary_rpc_method_handler(
          servicer.ModifyColumnFamilies,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ModifyColumnFamiliesRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Table.SerializeToString,
      ),
      'DropRowRange': grpc.unary_unary_rpc_method_handler(
          servicer.DropRowRange,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DropRowRangeRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GenerateConsistencyToken': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateConsistencyToken,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GenerateConsistencyTokenRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GenerateConsistencyTokenResponse.SerializeToString,
      ),
      'CheckConsistency': grpc.unary_unary_rpc_method_handler(
          servicer.CheckConsistency,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CheckConsistencyRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.CheckConsistencyResponse.SerializeToString,
      ),
      'SnapshotTable': grpc.unary_unary_rpc_method_handler(
          servicer.SnapshotTable,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.SnapshotTableRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'GetSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.GetSnapshot,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.GetSnapshotRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_table__pb2.Snapshot.SerializeToString,
      ),
      'ListSnapshots': grpc.unary_unary_rpc_method_handler(
          servicer.ListSnapshots,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListSnapshotsRequest.FromString,
          response_serializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.ListSnapshotsResponse.SerializeToString,
      ),
      'DeleteSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteSnapshot,
          request_deserializer=google_dot_bigtable_dot_admin_dot_v2_dot_bigtable__table__admin__pb2.DeleteSnapshotRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.bigtable.admin.v2.BigtableTableAdmin', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Copyright 2021 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""Spanner gRPC client. This class is automatically generated."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.core import gapic_util
from googlecloudsdk.generated_clients.gapic_clients import spanner_v1


class GapicWrapperClient(object):
  """Spanner client."""
  types = spanner_v1.types

  def __init__(self, credentials, **kwargs):
    """
    Instantiates the GapicWrapperClient for spanner_v1.

    Args:
      credentials: google.auth.credentials.Credentials, the credentials to use.
      **kwargs: Additional kwargs to pass to gapic.MakeClient.

    Returns:
        GapicWrapperClient
    """
    self.credentials = credentials
    self.spanner = gapic_util.MakeRestClient(
        spanner_v1.services.spanner.client.SpannerClient,
        credentials, **kwargs)



"""Generated message classes for bigquerydatatransfer version v1.

Schedule queries or transfer external data from SaaS applications to Google
BigQuery on a regular basis.
"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding
from apitools.base.py import extra_types


package = 'bigquerydatatransfer'


class BigquerydatatransferProjectsDataSourcesCheckValidCredsRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsDataSourcesCheckValidCredsRequest object.

  Fields:
    checkValidCredsRequest: A CheckValidCredsRequest resource to be passed as
      the request body.
    name: Required. The data source in the form:
      `projects/{project_id}/dataSources/{data_source_id}` or `projects/{proje
      ct_id}/locations/{location_id}/dataSources/{data_source_id}`.
  """

  checkValidCredsRequest = _messages.MessageField('CheckValidCredsRequest', 1)
  name = _messages.StringField(2, required=True)


class BigquerydatatransferProjectsDataSourcesGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsDataSourcesGetRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/dataSources/{data_source_id}` or `projec
      ts/{project_id}/locations/{location_id}/dataSources/{data_source_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsDataSourcesListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsDataSourcesListRequest object.

  Fields:
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListDataSourcesRequest` list results. For multiple-page results,
      `ListDataSourcesResponse` outputs a `next_page` token, which can be used
      as the `page_token` value to request the next page of list results.
    parent: Required. The BigQuery project id for which data sources should be
      returned. Must be in the form: `projects/{project_id}` or
      `projects/{project_id}/locations/{location_id}`
  """

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class BigquerydatatransferProjectsEnrollDataSourcesRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsEnrollDataSourcesRequest object.

  Fields:
    enrollDataSourcesRequest: A EnrollDataSourcesRequest resource to be passed
      as the request body.
    name: The name of the project resource in the form:
      `projects/{project_id}`
  """

  enrollDataSourcesRequest = _messages.MessageField('EnrollDataSourcesRequest', 1)
  name = _messages.StringField(2, required=True)


class BigquerydatatransferProjectsLocationsDataSourcesCheckValidCredsRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsDataSourcesCheckValidCredsRequest
  object.

  Fields:
    checkValidCredsRequest: A CheckValidCredsRequest resource to be passed as
      the request body.
    name: Required. The data source in the form:
      `projects/{project_id}/dataSources/{data_source_id}` or `projects/{proje
      ct_id}/locations/{location_id}/dataSources/{data_source_id}`.
  """

  checkValidCredsRequest = _messages.MessageField('CheckValidCredsRequest', 1)
  name = _messages.StringField(2, required=True)


class BigquerydatatransferProjectsLocationsDataSourcesGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsDataSourcesGetRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/dataSources/{data_source_id}` or `projec
      ts/{project_id}/locations/{location_id}/dataSources/{data_source_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsDataSourcesListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsDataSourcesListRequest object.

  Fields:
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListDataSourcesRequest` list results. For multiple-page results,
      `ListDataSourcesResponse` outputs a `next_page` token, which can be used
      as the `page_token` value to request the next page of list results.
    parent: Required. The BigQuery project id for which data sources should be
      returned. Must be in the form: `projects/{project_id}` or
      `projects/{project_id}/locations/{location_id}`
  """

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class BigquerydatatransferProjectsLocationsEnrollDataSourcesRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsEnrollDataSourcesRequest object.

  Fields:
    enrollDataSourcesRequest: A EnrollDataSourcesRequest resource to be passed
      as the request body.
    name: The name of the project resource in the form:
      `projects/{project_id}`
  """

  enrollDataSourcesRequest = _messages.MessageField('EnrollDataSourcesRequest', 1)
  name = _messages.StringField(2, required=True)


class BigquerydatatransferProjectsLocationsGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsGetRequest object.

  Fields:
    name: Resource name for the location.
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsListRequest object.

  Fields:
    filter: A filter to narrow down results to a preferred subset. The
      filtering language accepts strings like `"displayName=tokyo"`, and is
      documented in more detail in [AIP-160](https://google.aip.dev/160).
    name: The resource that owns the locations collection, if applicable.
    pageSize: The maximum number of results to return. If not set, the service
      selects a default.
    pageToken: A page token received from the `next_page_token` field in the
      response. Send that page token to receive the subsequent page.
  """

  filter = _messages.StringField(1)
  name = _messages.StringField(2, required=True)
  pageSize = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)


class BigquerydatatransferProjectsLocationsTransferConfigsCreateRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsCreateRequest
  object.

  Fields:
    authorizationCode: Optional OAuth2 authorization code to use with this
      transfer configuration. This is required only if
      `transferConfig.dataSourceId` is 'youtube_channel' and new credentials
      are needed, as indicated by `CheckValidCreds`. In order to obtain
      authorization_code, make a request to the following URL: https://www.gst
      atic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oauth
      :2.0:oob&response_type=authorization_code&client_id=client_id&scope=data
      _source_scopes * The client_id is the OAuth client_id of the a data
      source as returned by ListDataSources method. * data_source_scopes are
      the scopes returned by ListDataSources method. Note that this should not
      be set when `service_account_name` is used to create the transfer
      config.
    parent: Required. The BigQuery project id where the transfer configuration
      should be created. Must be in the format
      projects/{project_id}/locations/{location_id} or projects/{project_id}.
      If specified location and location of the destination bigquery dataset
      do not match - the request will fail.
    serviceAccountName: Optional service account email. If this field is set,
      the transfer config will be created with this service account's
      credentials. It requires that the requesting user calling this API has
      permissions to act as this service account. Note that not all data
      sources support service account credentials when creating a transfer
      config. For the latest list of data sources, read about [using service
      accounts](https://cloud.google.com/bigquery-transfer/docs/use-service-
      accounts).
    transferConfig: A TransferConfig resource to be passed as the request
      body.
    versionInfo: Optional version info. This is required only if
      `transferConfig.dataSourceId` is not 'youtube_channel' and new
      credentials are needed, as indicated by `CheckValidCreds`. In order to
      obtain version info, make a request to the following URL: https://www.gs
      tatic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oaut
      h:2.0:oob&response_type=version_info&client_id=client_id&scope=data_sour
      ce_scopes * The client_id is the OAuth client_id of the a data source as
      returned by ListDataSources method. * data_source_scopes are the scopes
      returned by ListDataSources method. Note that this should not be set
      when `service_account_name` is used to create the transfer config.
  """

  authorizationCode = _messages.StringField(1)
  parent = _messages.StringField(2, required=True)
  serviceAccountName = _messages.StringField(3)
  transferConfig = _messages.MessageField('TransferConfig', 4)
  versionInfo = _messages.StringField(5)


class BigquerydatatransferProjectsLocationsTransferConfigsDeleteRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsDeleteRequest
  object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/transferConfigs/{config_id}` or `project
      s/{project_id}/locations/{location_id}/transferConfigs/{config_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsGetRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/transferConfigs/{config_id}` or `project
      s/{project_id}/locations/{location_id}/transferConfigs/{config_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsListRequest
  object.

  Fields:
    dataSourceIds: When specified, only configurations of requested data
      sources are returned.
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransfersRequest` list results. For multiple-page results,
      `ListTransfersResponse` outputs a `next_page` token, which can be used
      as the `page_token` value to request the next page of list results.
    parent: Required. The BigQuery project id for which transfer configs
      should be returned: `projects/{project_id}` or
      `projects/{project_id}/locations/{location_id}`
  """

  dataSourceIds = _messages.StringField(1, repeated=True)
  pageSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  parent = _messages.StringField(4, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsPatchRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsPatchRequest
  object.

  Fields:
    authorizationCode: Optional OAuth2 authorization code to use with this
      transfer configuration. This is required only if
      `transferConfig.dataSourceId` is 'youtube_channel' and new credentials
      are needed, as indicated by `CheckValidCreds`. In order to obtain
      authorization_code, make a request to the following URL: https://www.gst
      atic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oauth
      :2.0:oob&response_type=authorization_code&client_id=client_id&scope=data
      _source_scopes * The client_id is the OAuth client_id of the a data
      source as returned by ListDataSources method. * data_source_scopes are
      the scopes returned by ListDataSources method. Note that this should not
      be set when `service_account_name` is used to update the transfer
      config.
    name: The resource name of the transfer config. Transfer config names have
      the form
      `projects/{project_id}/locations/{region}/transferConfigs/{config_id}`.
      Where `config_id` is usually a uuid, even though it is not guaranteed or
      required. The name is ignored when creating a transfer config.
    serviceAccountName: Optional service account email. If this field is set,
      the transfer config will be created with this service account's
      credentials. It requires that the requesting user calling this API has
      permissions to act as this service account. Note that not all data
      sources support service account credentials when creating a transfer
      config. For the latest list of data sources, read about [using service
      accounts](https://cloud.google.com/bigquery-transfer/docs/use-service-
      accounts).
    transferConfig: A TransferConfig resource to be passed as the request
      body.
    updateMask: Required. Required list of fields to be updated in this
      request.
    versionInfo: Optional version info. This is required only if
      `transferConfig.dataSourceId` is not 'youtube_channel' and new
      credentials are needed, as indicated by `CheckValidCreds`. In order to
      obtain version info, make a request to the following URL: https://www.gs
      tatic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oaut
      h:2.0:oob&response_type=version_info&client_id=client_id&scope=data_sour
      ce_scopes * The client_id is the OAuth client_id of the a data source as
      returned by ListDataSources method. * data_source_scopes are the scopes
      returned by ListDataSources method. Note that this should not be set
      when `service_account_name` is used to update the transfer config.
  """

  authorizationCode = _messages.StringField(1)
  name = _messages.StringField(2, required=True)
  serviceAccountName = _messages.StringField(3)
  transferConfig = _messages.MessageField('TransferConfig', 4)
  updateMask = _messages.StringField(5)
  versionInfo = _messages.StringField(6)


class BigquerydatatransferProjectsLocationsTransferConfigsRunsDeleteRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsRunsDeleteRequest
  object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsRunsGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsRunsGetRequest
  object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsRunsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsRunsListRequest
  object.

  Enums:
    RunAttemptValueValuesEnum: Indicates how run attempts are to be pulled.
    StatesValueValuesEnum: When specified, only transfer runs with requested
      states are returned.

  Fields:
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransferRunsRequest` list results. For multiple-page results,
      `ListTransferRunsResponse` outputs a `next_page` token, which can be
      used as the `page_token` value to request the next page of list results.
    parent: Required. Name of transfer configuration for which transfer runs
      should be retrieved. Format of transfer configuration resource name is:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    runAttempt: Indicates how run attempts are to be pulled.
    states: When specified, only transfer runs with requested states are
      returned.
  """

  class RunAttemptValueValuesEnum(_messages.Enum):
    r"""Indicates how run attempts are to be pulled.

    Values:
      RUN_ATTEMPT_UNSPECIFIED: All runs should be returned.
      LATEST: Only latest run per day should be returned.
    """
    RUN_ATTEMPT_UNSPECIFIED = 0
    LATEST = 1

  class StatesValueValuesEnum(_messages.Enum):
    r"""When specified, only transfer runs with requested states are returned.

    Values:
      TRANSFER_STATE_UNSPECIFIED: State placeholder (0).
      PENDING: Data transfer is scheduled and is waiting to be picked up by
        data transfer backend (2).
      RUNNING: Data transfer is in progress (3).
      SUCCEEDED: Data transfer completed successfully (4).
      FAILED: Data transfer failed (5).
      CANCELLED: Data transfer is cancelled (6).
    """
    TRANSFER_STATE_UNSPECIFIED = 0
    PENDING = 1
    RUNNING = 2
    SUCCEEDED = 3
    FAILED = 4
    CANCELLED = 5

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)
  runAttempt = _messages.EnumField('RunAttemptValueValuesEnum', 4)
  states = _messages.EnumField('StatesValueValuesEnum', 5, repeated=True)


class BigquerydatatransferProjectsLocationsTransferConfigsRunsTransferLogsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsLocationsTransferConfigsRunsTransferLogsLi
  stRequest object.

  Enums:
    MessageTypesValueValuesEnum: Message types to return. If not populated -
      INFO, WARNING and ERROR messages are returned.

  Fields:
    messageTypes: Message types to return. If not populated - INFO, WARNING
      and ERROR messages are returned.
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransferLogsRequest` list results. For multiple-page results,
      `ListTransferLogsResponse` outputs a `next_page` token, which can be
      used as the `page_token` value to request the next page of list results.
    parent: Required. Transfer run name in the form:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  class MessageTypesValueValuesEnum(_messages.Enum):
    r"""Message types to return. If not populated - INFO, WARNING and ERROR
    messages are returned.

    Values:
      MESSAGE_SEVERITY_UNSPECIFIED: No severity specified.
      INFO: Informational message.
      WARNING: Warning message.
      ERROR: Error message.
    """
    MESSAGE_SEVERITY_UNSPECIFIED = 0
    INFO = 1
    WARNING = 2
    ERROR = 3

  messageTypes = _messages.EnumField('MessageTypesValueValuesEnum', 1, repeated=True)
  pageSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  parent = _messages.StringField(4, required=True)


class BigquerydatatransferProjectsLocationsTransferConfigsScheduleRunsRequest(_messages.Message):
  r"""A
  BigquerydatatransferProjectsLocationsTransferConfigsScheduleRunsRequest
  object.

  Fields:
    parent: Required. Transfer configuration name in the form:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    scheduleTransferRunsRequest: A ScheduleTransferRunsRequest resource to be
      passed as the request body.
  """

  parent = _messages.StringField(1, required=True)
  scheduleTransferRunsRequest = _messages.MessageField('ScheduleTransferRunsRequest', 2)


class BigquerydatatransferProjectsLocationsTransferConfigsStartManualRunsRequest(_messages.Message):
  r"""A
  BigquerydatatransferProjectsLocationsTransferConfigsStartManualRunsRequest
  object.

  Fields:
    parent: Transfer configuration name in the form:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    startManualTransferRunsRequest: A StartManualTransferRunsRequest resource
      to be passed as the request body.
  """

  parent = _messages.StringField(1, required=True)
  startManualTransferRunsRequest = _messages.MessageField('StartManualTransferRunsRequest', 2)


class BigquerydatatransferProjectsTransferConfigsCreateRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsCreateRequest object.

  Fields:
    authorizationCode: Optional OAuth2 authorization code to use with this
      transfer configuration. This is required only if
      `transferConfig.dataSourceId` is 'youtube_channel' and new credentials
      are needed, as indicated by `CheckValidCreds`. In order to obtain
      authorization_code, make a request to the following URL: https://www.gst
      atic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oauth
      :2.0:oob&response_type=authorization_code&client_id=client_id&scope=data
      _source_scopes * The client_id is the OAuth client_id of the a data
      source as returned by ListDataSources method. * data_source_scopes are
      the scopes returned by ListDataSources method. Note that this should not
      be set when `service_account_name` is used to create the transfer
      config.
    parent: Required. The BigQuery project id where the transfer configuration
      should be created. Must be in the format
      projects/{project_id}/locations/{location_id} or projects/{project_id}.
      If specified location and location of the destination bigquery dataset
      do not match - the request will fail.
    serviceAccountName: Optional service account email. If this field is set,
      the transfer config will be created with this service account's
      credentials. It requires that the requesting user calling this API has
      permissions to act as this service account. Note that not all data
      sources support service account credentials when creating a transfer
      config. For the latest list of data sources, read about [using service
      accounts](https://cloud.google.com/bigquery-transfer/docs/use-service-
      accounts).
    transferConfig: A TransferConfig resource to be passed as the request
      body.
    versionInfo: Optional version info. This is required only if
      `transferConfig.dataSourceId` is not 'youtube_channel' and new
      credentials are needed, as indicated by `CheckValidCreds`. In order to
      obtain version info, make a request to the following URL: https://www.gs
      tatic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oaut
      h:2.0:oob&response_type=version_info&client_id=client_id&scope=data_sour
      ce_scopes * The client_id is the OAuth client_id of the a data source as
      returned by ListDataSources method. * data_source_scopes are the scopes
      returned by ListDataSources method. Note that this should not be set
      when `service_account_name` is used to create the transfer config.
  """

  authorizationCode = _messages.StringField(1)
  parent = _messages.StringField(2, required=True)
  serviceAccountName = _messages.StringField(3)
  transferConfig = _messages.MessageField('TransferConfig', 4)
  versionInfo = _messages.StringField(5)


class BigquerydatatransferProjectsTransferConfigsDeleteRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsDeleteRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/transferConfigs/{config_id}` or `project
      s/{project_id}/locations/{location_id}/transferConfigs/{config_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsTransferConfigsGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsGetRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example: `projects/{project_id}/transferConfigs/{config_id}` or `project
      s/{project_id}/locations/{location_id}/transferConfigs/{config_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsTransferConfigsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsListRequest object.

  Fields:
    dataSourceIds: When specified, only configurations of requested data
      sources are returned.
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransfersRequest` list results. For multiple-page results,
      `ListTransfersResponse` outputs a `next_page` token, which can be used
      as the `page_token` value to request the next page of list results.
    parent: Required. The BigQuery project id for which transfer configs
      should be returned: `projects/{project_id}` or
      `projects/{project_id}/locations/{location_id}`
  """

  dataSourceIds = _messages.StringField(1, repeated=True)
  pageSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  parent = _messages.StringField(4, required=True)


class BigquerydatatransferProjectsTransferConfigsPatchRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsPatchRequest object.

  Fields:
    authorizationCode: Optional OAuth2 authorization code to use with this
      transfer configuration. This is required only if
      `transferConfig.dataSourceId` is 'youtube_channel' and new credentials
      are needed, as indicated by `CheckValidCreds`. In order to obtain
      authorization_code, make a request to the following URL: https://www.gst
      atic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oauth
      :2.0:oob&response_type=authorization_code&client_id=client_id&scope=data
      _source_scopes * The client_id is the OAuth client_id of the a data
      source as returned by ListDataSources method. * data_source_scopes are
      the scopes returned by ListDataSources method. Note that this should not
      be set when `service_account_name` is used to update the transfer
      config.
    name: The resource name of the transfer config. Transfer config names have
      the form
      `projects/{project_id}/locations/{region}/transferConfigs/{config_id}`.
      Where `config_id` is usually a uuid, even though it is not guaranteed or
      required. The name is ignored when creating a transfer config.
    serviceAccountName: Optional service account email. If this field is set,
      the transfer config will be created with this service account's
      credentials. It requires that the requesting user calling this API has
      permissions to act as this service account. Note that not all data
      sources support service account credentials when creating a transfer
      config. For the latest list of data sources, read about [using service
      accounts](https://cloud.google.com/bigquery-transfer/docs/use-service-
      accounts).
    transferConfig: A TransferConfig resource to be passed as the request
      body.
    updateMask: Required. Required list of fields to be updated in this
      request.
    versionInfo: Optional version info. This is required only if
      `transferConfig.dataSourceId` is not 'youtube_channel' and new
      credentials are needed, as indicated by `CheckValidCreds`. In order to
      obtain version info, make a request to the following URL: https://www.gs
      tatic.com/bigquerydatatransfer/oauthz/auth?redirect_uri=urn:ietf:wg:oaut
      h:2.0:oob&response_type=version_info&client_id=client_id&scope=data_sour
      ce_scopes * The client_id is the OAuth client_id of the a data source as
      returned by ListDataSources method. * data_source_scopes are the scopes
      returned by ListDataSources method. Note that this should not be set
      when `service_account_name` is used to update the transfer config.
  """

  authorizationCode = _messages.StringField(1)
  name = _messages.StringField(2, required=True)
  serviceAccountName = _messages.StringField(3)
  transferConfig = _messages.MessageField('TransferConfig', 4)
  updateMask = _messages.StringField(5)
  versionInfo = _messages.StringField(6)


class BigquerydatatransferProjectsTransferConfigsRunsDeleteRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsRunsDeleteRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsTransferConfigsRunsGetRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsRunsGetRequest object.

  Fields:
    name: Required. The field will contain name of the resource requested, for
      example:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  name = _messages.StringField(1, required=True)


class BigquerydatatransferProjectsTransferConfigsRunsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsRunsListRequest object.

  Enums:
    RunAttemptValueValuesEnum: Indicates how run attempts are to be pulled.
    StatesValueValuesEnum: When specified, only transfer runs with requested
      states are returned.

  Fields:
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransferRunsRequest` list results. For multiple-page results,
      `ListTransferRunsResponse` outputs a `next_page` token, which can be
      used as the `page_token` value to request the next page of list results.
    parent: Required. Name of transfer configuration for which transfer runs
      should be retrieved. Format of transfer configuration resource name is:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    runAttempt: Indicates how run attempts are to be pulled.
    states: When specified, only transfer runs with requested states are
      returned.
  """

  class RunAttemptValueValuesEnum(_messages.Enum):
    r"""Indicates how run attempts are to be pulled.

    Values:
      RUN_ATTEMPT_UNSPECIFIED: All runs should be returned.
      LATEST: Only latest run per day should be returned.
    """
    RUN_ATTEMPT_UNSPECIFIED = 0
    LATEST = 1

  class StatesValueValuesEnum(_messages.Enum):
    r"""When specified, only transfer runs with requested states are returned.

    Values:
      TRANSFER_STATE_UNSPECIFIED: State placeholder (0).
      PENDING: Data transfer is scheduled and is waiting to be picked up by
        data transfer backend (2).
      RUNNING: Data transfer is in progress (3).
      SUCCEEDED: Data transfer completed successfully (4).
      FAILED: Data transfer failed (5).
      CANCELLED: Data transfer is cancelled (6).
    """
    TRANSFER_STATE_UNSPECIFIED = 0
    PENDING = 1
    RUNNING = 2
    SUCCEEDED = 3
    FAILED = 4
    CANCELLED = 5

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)
  runAttempt = _messages.EnumField('RunAttemptValueValuesEnum', 4)
  states = _messages.EnumField('StatesValueValuesEnum', 5, repeated=True)


class BigquerydatatransferProjectsTransferConfigsRunsTransferLogsListRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsRunsTransferLogsListRequest
  object.

  Enums:
    MessageTypesValueValuesEnum: Message types to return. If not populated -
      INFO, WARNING and ERROR messages are returned.

  Fields:
    messageTypes: Message types to return. If not populated - INFO, WARNING
      and ERROR messages are returned.
    pageSize: Page size. The default page size is the maximum value of 1000
      results.
    pageToken: Pagination token, which can be used to request a specific page
      of `ListTransferLogsRequest` list results. For multiple-page results,
      `ListTransferLogsResponse` outputs a `next_page` token, which can be
      used as the `page_token` value to request the next page of list results.
    parent: Required. Transfer run name in the form:
      `projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}` or `pr
      ojects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/
      runs/{run_id}`
  """

  class MessageTypesValueValuesEnum(_messages.Enum):
    r"""Message types to return. If not populated - INFO, WARNING and ERROR
    messages are returned.

    Values:
      MESSAGE_SEVERITY_UNSPECIFIED: No severity specified.
      INFO: Informational message.
      WARNING: Warning message.
      ERROR: Error message.
    """
    MESSAGE_SEVERITY_UNSPECIFIED = 0
    INFO = 1
    WARNING = 2
    ERROR = 3

  messageTypes = _messages.EnumField('MessageTypesValueValuesEnum', 1, repeated=True)
  pageSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  parent = _messages.StringField(4, required=True)


class BigquerydatatransferProjectsTransferConfigsScheduleRunsRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsScheduleRunsRequest object.

  Fields:
    parent: Required. Transfer configuration name in the form:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    scheduleTransferRunsRequest: A ScheduleTransferRunsRequest resource to be
      passed as the request body.
  """

  parent = _messages.StringField(1, required=True)
  scheduleTransferRunsRequest = _messages.MessageField('ScheduleTransferRunsRequest', 2)


class BigquerydatatransferProjectsTransferConfigsStartManualRunsRequest(_messages.Message):
  r"""A BigquerydatatransferProjectsTransferConfigsStartManualRunsRequest
  object.

  Fields:
    parent: Transfer configuration name in the form:
      `projects/{project_id}/transferConfigs/{config_id}` or `projects/{projec
      t_id}/locations/{location_id}/transferConfigs/{config_id}`.
    startManualTransferRunsRequest: A StartManualTransferRunsRequest resource
      to be passed as the request body.
  """

  parent = _messages.StringField(1, required=True)
  startManualTransferRunsRequest = _messages.MessageField('StartManualTransferRunsRequest', 2)


class CheckValidCredsRequest(_messages.Message):
  r"""A request to determine whether the user has valid credentials. This
  method is used to limit the number of OAuth popups in the user interface.
  The user id is inferred from the API call context. If the data source has
  the Google+ authorization type, this method returns false, as it cannot be
  determined whether the credentials are already valid merely based on the
  user id.
  """



class CheckValidCredsResponse(_messages.Message):
  r"""A response indicating whether the credentials exist and are valid.

  Fields:
    hasValidCreds: If set to `true`, the credentials exist and are valid.
  """

  hasValidCreds = _messages.BooleanField(1)


class DataSource(_messages.Message):
  r"""Defines the properties and custom parameters for a data source.

  Enums:
    AuthorizationTypeValueValuesEnum: Indicates the type of authorization.
    DataRefreshTypeValueValuesEnum: Specifies whether the data source supports
      automatic data refresh for the past few days, and how it's supported.
      For some data sources, data might not be complete until a few days
      later, so it's useful to refresh data automatically.
    TransferTypeValueValuesEnum: Deprecated. This field has no effect.

  Fields:
    authorizationType: Indicates the type of authorization.
    clientId: Data source client id which should be used to receive refresh
      token.
    dataRefreshType: Specifies whether the data source supports automatic data
      refresh for the past few days, and how it's supported. For some data
      sources, data might not be complete until a few days later, so it's
      useful to refresh data automatically.
    dataSourceId: Data source id.
    defaultDataRefreshWindowDays: Default data refresh window on days. Only
      meaningful when `data_refresh_type` = `SLIDING_WINDOW`.
    defaultSchedule: Default data transfer schedule. Examples of valid
      schedules include: `1st,3rd monday of month 15:30`, `every wed,fri of
      jan,jun 13:15`, and `first sunday of quarter 00:00`.
    description: User friendly data source description string.
    displayName: User friendly data source name.
    helpUrl: Url for the help document for this data source.
    manualRunsDisabled: Disables backfilling and manual run scheduling for the
      data source.
    minimumScheduleInterval: The minimum interval for scheduler to schedule
      runs.
    name: Output only. Data source resource name.
    parameters: Data source parameters.
    scopes: Api auth scopes for which refresh token needs to be obtained.
      These are scopes needed by a data source to prepare data and ingest them
      into BigQuery, e.g., https://www.googleapis.com/auth/bigquery
    supportsCustomSchedule: Specifies whether the data source supports a user
      defined schedule, or operates on the default schedule. When set to
      `true`, user can override default schedule.
    supportsMultipleTransfers: Deprecated. This field has no effect.
    transferType: Deprecated. This field has no effect.
    updateDeadlineSeconds: The number of seconds to wait for an update from
      the data source before the Data Transfer Service marks the transfer as
      FAILED.
  """

  class AuthorizationTypeValueValuesEnum(_messages.Enum):
    r"""Indicates the type of authorization.

    Values:
      AUTHORIZATION_TYPE_UNSPECIFIED: Type unspecified.
      AUTHORIZATION_CODE: Use OAuth 2 authorization codes that can be
        exchanged for a refresh token on the backend.
      GOOGLE_PLUS_AUTHORIZATION_CODE: Return an authorization code for a given
        Google+ page that can then be exchanged for a refresh token on the
        backend.
      FIRST_PARTY_OAUTH: Use First Party OAuth.
    """
    AUTHORIZATION_TYPE_UNSPECIFIED = 0
    AUTHORIZATION_CODE = 1
    GOOGLE_PLUS_AUTHORIZATION_CODE = 2
    FIRST_PARTY_OAUTH = 3

  class DataRefreshTypeValueValuesEnum(_messages.Enum):
    r"""Specifies whether the data source supports automatic data refresh for
    the past few days, and how it's supported. For some data sources, data
    might not be complete until a few days later, so it's useful to refresh
    data automatically.

    Values:
      DATA_REFRESH_TYPE_UNSPECIFIED: The data source won't support data auto
        refresh, which is default value.
      SLIDING_WINDOW: The data source supports data auto refresh, and runs
        will be scheduled for the past few days. Does not allow custom values
        to be set for each transfer config.
      CUSTOM_SLIDING_WINDOW: The data source supports data auto refresh, and
        runs will be scheduled for the past few days. Allows custom values to
        be set for each transfer config.
    """
    DATA_REFRESH_TYPE_UNSPECIFIED = 0
    SLIDING_WINDOW = 1
    CUSTOM_SLIDING_WINDOW = 2

  class TransferTypeValueValuesEnum(_messages.Enum):
    r"""Deprecated. This field has no effect.

    Values:
      TRANSFER_TYPE_UNSPECIFIED: Invalid or Unknown transfer type placeholder.
      BATCH: Batch data transfer.
      STREAMING: Streaming data transfer. Streaming data source currently
        doesn't support multiple transfer configs per project.
    """
    TRANSFER_TYPE_UNSPECIFIED = 0
    BATCH = 1
    STREAMING = 2

  authorizationType = _messages.EnumField('AuthorizationTypeValueValuesEnum', 1)
  clientId = _messages.StringField(2)
  dataRefreshType = _messages.EnumField('DataRefreshTypeValueValuesEnum', 3)
  dataSourceId = _messages.StringField(4)
  defaultDataRefreshWindowDays = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  defaultSchedule = _messages.StringField(6)
  description = _messages.StringField(7)
  displayName = _messages.StringField(8)
  helpUrl = _messages.StringField(9)
  manualRunsDisabled = _messages.BooleanField(10)
  minimumScheduleInterval = _messages.StringField(11)
  name = _messages.StringField(12)
  parameters = _messages.MessageField('DataSourceParameter', 13, repeated=True)
  scopes = _messages.StringField(14, repeated=True)
  supportsCustomSchedule = _messages.BooleanField(15)
  supportsMultipleTransfers = _messages.BooleanField(16)
  transferType = _messages.EnumField('TransferTypeValueValuesEnum', 17)
  updateDeadlineSeconds = _messages.IntegerField(18, variant=_messages.Variant.INT32)


class DataSourceParameter(_messages.Message):
  r"""A parameter used to define custom fields in a data source definition.

  Enums:
    TypeValueValuesEnum: Parameter type.

  Fields:
    allowedValues: All possible values for the parameter.
    deprecated: If true, it should not be used in new transfers, and it should
      not be visible to users.
    description: Parameter description.
    displayName: Parameter display name in the user interface.
    fields: Deprecated. This field has no effect.
    immutable: Cannot be changed after initial creation.
    maxValue: For integer and double values specifies maximum allowed value.
    minValue: For integer and double values specifies minimum allowed value.
    paramId: Parameter identifier.
    recurse: Deprecated. This field has no effect.
    repeated: Deprecated. This field has no effect.
    required: Is parameter required.
    type: Parameter type.
    validationDescription: Description of the requirements for this field, in
      case the user input does not fulfill the regex pattern or min/max
      values.
    validationHelpUrl: URL to a help document to further explain the naming
      requirements.
    validationRegex: Regular expression which can be used for parameter
      validation.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Parameter type.

    Values:
      TYPE_UNSPECIFIED: Type unspecified.
      STRING: String parameter.
      INTEGER: Integer parameter (64-bits). Will be serialized to json as
        string.
      DOUBLE: Double precision floating point parameter.
      BOOLEAN: Boolean parameter.
      RECORD: Deprecated. This field has no effect.
      PLUS_PAGE: Page ID for a Google+ Page.
    """
    TYPE_UNSPECIFIED = 0
    STRING = 1
    INTEGER = 2
    DOUBLE = 3
    BOOLEAN = 4
    RECORD = 5
    PLUS_PAGE = 6

  allowedValues = _messages.StringField(1, repeated=True)
  deprecated = _messages.BooleanField(2)
  description = _messages.StringField(3)
  displayName = _messages.StringField(4)
  fields = _messages.MessageField('DataSourceParameter', 5, repeated=True)
  immutable = _messages.BooleanField(6)
  maxValue = _messages.FloatField(7)
  minValue = _messages.FloatField(8)
  paramId = _messages.StringField(9)
  recurse = _messages.BooleanField(10)
  repeated = _messages.BooleanField(11)
  required = _messages.BooleanField(12)
  type = _messages.EnumField('TypeValueValuesEnum', 13)
  validationDescription = _messages.StringField(14)
  validationHelpUrl = _messages.StringField(15)
  validationRegex = _messages.StringField(16)


class EmailPreferences(_messages.Message):
  r"""Represents preferences for sending email notifications for transfer run
  events.

  Fields:
    enableFailureEmail: If true, email notifications will be sent on transfer
      run failures.
  """

  enableFailureEmail = _messages.BooleanField(1)


class Empty(_messages.Message):
  r"""A generic empty message that you can re-use to avoid defining duplicated
  empty messages in your APIs. A typical example is to use it as the request
  or the response type of an API method. For instance: service Foo { rpc
  Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
  """



class EnrollDataSourcesRequest(_messages.Message):
  r"""A request to enroll a set of data sources so they are visible in the
  BigQuery UI's `Transfer` tab.

  Fields:
    dataSourceIds: Data sources that are enrolled. It is required to provide
      at least one data source id.
  """

  dataSourceIds = _messages.StringField(1, repeated=True)


class ListDataSourcesResponse(_messages.Message):
  r"""Returns list of supported data sources and their metadata.

  Fields:
    dataSources: List of supported data sources and their transfer settings.
    nextPageToken: Output only. The next-pagination token. For multiple-page
      list results, this token can be used as the
      `ListDataSourcesRequest.page_token` to request the next page of list
      results.
  """

  dataSources = _messages.MessageField('DataSource', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class ListLocationsResponse(_messages.Message):
  r"""The response message for Locations.ListLocations.

  Fields:
    locations: A list of locations that matches the specified filter in the
      request.
    nextPageToken: The standard List next-page token.
  """

  locations = _messages.MessageField('Location', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class ListTransferConfigsResponse(_messages.Message):
  r"""The returned list of pipelines in the project.

  Fields:
    nextPageToken: Output only. The next-pagination token. For multiple-page
      list results, this token can be used as the
      `ListTransferConfigsRequest.page_token` to request the next page of list
      results.
    transferConfigs: Output only. The stored pipeline transfer configurations.
  """

  nextPageToken = _messages.StringField(1)
  transferConfigs = _messages.MessageField('TransferConfig', 2, repeated=True)


class ListTransferLogsResponse(_messages.Message):
  r"""The returned list transfer run messages.

  Fields:
    nextPageToken: Output only. The next-pagination token. For multiple-page
      list results, this token can be used as the
      `GetTransferRunLogRequest.page_token` to request the next page of list
      results.
    transferMessages: Output only. The stored pipeline transfer messages.
  """

  nextPageToken = _messages.StringField(1)
  transferMessages = _messages.MessageField('TransferMessage', 2, repeated=True)


class ListTransferRunsResponse(_messages.Message):
  r"""The returned list of pipelines in the project.

  Fields:
    nextPageToken: Output only. The next-pagination token. For multiple-page
      list results, this token can be used as the
      `ListTransferRunsRequest.page_token` to request the next page of list
      results.
    transferRuns: Output only. The stored pipeline transfer runs.
  """

  nextPageToken = _messages.StringField(1)
  transferRuns = _messages.MessageField('TransferRun', 2, repeated=True)


class Location(_messages.Message):
  r"""A resource that represents Google Cloud Platform location.

  Messages:
    LabelsValue: Cross-service attributes for the location. For example
      {"cloud.googleapis.com/region": "us-east1"}
    MetadataValue: Service-specific metadata. For example the available
      capacity at the given location.

  Fields:
    displayName: The friendly name for this location, typically a nearby city
      name. For example, "Tokyo".
    labels: Cross-service attributes for the location. For example
      {"cloud.googleapis.com/region": "us-east1"}
    locationId: The canonical id for this location. For example: `"us-east1"`.
    metadata: Service-specific metadata. For example the available capacity at
      the given location.
    name: Resource name for the location, which may vary between
      implementations. For example: `"projects/example-project/locations/us-
      east1"`
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Cross-service attributes for the location. For example
    {"cloud.googleapis.com/region": "us-east1"}

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""Service-specific metadata. For example the available capacity at the
    given location.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  displayName = _messages.StringField(1)
  labels = _messages.MessageField('LabelsValue', 2)
  locationId = _messages.StringField(3)
  metadata = _messages.MessageField('MetadataValue', 4)
  name = _messages.StringField(5)


class ScheduleOptions(_messages.Message):
  r"""Options customizing the data transfer schedule.

  Fields:
    disableAutoScheduling: If true, automatic scheduling of data transfer runs
      for this configuration will be disabled. The runs can be started on ad-
      hoc basis using StartManualTransferRuns API. When automatic scheduling
      is disabled, the TransferConfig.schedule field will be ignored.
    endTime: Defines time to stop scheduling transfer runs. A transfer run
      cannot be scheduled at or after the end time. The end time can be
      changed at any moment. The time when a data transfer can be trigerred
      manually is not limited by this option.
    startTime: Specifies time to start scheduling transfer runs. The first run
      will be scheduled at or after the start time according to a recurrence
      pattern defined in the schedule string. The start time can be changed at
      any moment. The time when a data transfer can be trigerred manually is
      not limited by this option.
  """

  disableAutoScheduling = _messages.BooleanField(1)
  endTime = _messages.StringField(2)
  startTime = _messages.StringField(3)


class ScheduleTransferRunsRequest(_messages.Message):
  r"""A request to schedule transfer runs for a time range.

  Fields:
    endTime: Required. End time of the range of transfer runs. For example,
      `"2017-05-30T00:00:00+00:00"`.
    startTime: Required. Start time of the range of transfer runs. For
      example, `"2017-05-25T00:00:00+00:00"`.
  """

  endTime = _messages.StringField(1)
  startTime = _messages.StringField(2)


class ScheduleTransferRunsResponse(_messages.Message):
  r"""A response to schedule transfer runs for a time range.

  Fields:
    runs: The transfer runs that were scheduled.
  """

  runs = _messages.MessageField('TransferRun', 1, repeated=True)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    FXgafvValueValuesEnum: V1 error format.
    AltValueValuesEnum: Data format for response.

  Fields:
    f__xgafv: V1 error format.
    access_token: OAuth access token.
    alt: Data format for response.
    callback: JSONP
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: Available to use for quota purposes for server-side
      applications. Can be any arbitrary string assigned to a user, but should
      not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    uploadType: Legacy upload protocol for media (e.g. "media", "multipart").
    upload_protocol: Upload protocol for media (e.g. "raw", "multipart").
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for response.

    Values:
      json: Responses with Content-Type of application/json
      media: Media download with context-dependent Content-Type
      proto: Responses with Content-Type of application/x-protobuf
    """
    json = 0
    media = 1
    proto = 2

  class FXgafvValueValuesEnum(_messages.Enum):
    r"""V1 error format.

    Values:
      _1: v1 error format
      _2: v2 error format
    """
    _1 = 0
    _2 = 1

  f__xgafv = _messages.EnumField('FXgafvValueValuesEnum', 1)
  access_token = _messages.StringField(2)
  alt = _messages.EnumField('AltValueValuesEnum', 3, default='json')
  callback = _messages.StringField(4)
  fields = _messages.StringField(5)
  key = _messages.StringField(6)
  oauth_token = _messages.StringField(7)
  prettyPrint = _messages.BooleanField(8, default=True)
  quotaUser = _messages.StringField(9)
  trace = _messages.StringField(10)
  uploadType = _messages.StringField(11)
  upload_protocol = _messages.StringField(12)


class StartManualTransferRunsRequest(_messages.Message):
  r"""A request to start manual transfer runs.

  Fields:
    requestedRunTime: Specific run_time for a transfer run to be started. The
      requested_run_time must not be in the future.
    requestedTimeRange: Time range for the transfer runs that should be
      started.
  """

  requestedRunTime = _messages.StringField(1)
  requestedTimeRange = _messages.MessageField('TimeRange', 2)


class StartManualTransferRunsResponse(_messages.Message):
  r"""A response to start manual transfer runs.

  Fields:
    runs: The transfer runs that were created.
  """

  runs = _messages.MessageField('TransferRun', 1, repeated=True)


class Status(_messages.Message):
  r"""The `Status` type defines a logical error model that is suitable for
  different programming environments, including REST APIs and RPC APIs. It is
  used by [gRPC](https://github.com/grpc). Each `Status` message contains
  three pieces of data: error code, error message, and error details. You can
  find out more about this error model and how to work with it in the [API
  Design Guide](https://cloud.google.com/apis/design/errors).

  Messages:
    DetailsValueListEntry: A DetailsValueListEntry object.

  Fields:
    code: The status code, which should be an enum value of google.rpc.Code.
    details: A list of messages that carry the error details. There is a
      common set of message types for APIs to use.
    message: A developer-facing error message, which should be in English. Any
      user-facing error message should be localized and sent in the
      google.rpc.Status.details field, or localized by the client.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DetailsValueListEntry(_messages.Message):
    r"""A DetailsValueListEntry object.

    Messages:
      AdditionalProperty: An additional property for a DetailsValueListEntry
        object.

    Fields:
      additionalProperties: Properties of the object. Contains field @type
        with type URL.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DetailsValueListEntry object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  code = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  details = _messages.MessageField('DetailsValueListEntry', 2, repeated=True)
  message = _messages.StringField(3)


class TimeRange(_messages.Message):
  r"""A specification for a time range, this will request transfer runs with
  run_time between start_time (inclusive) and end_time (exclusive).

  Fields:
    endTime: End time of the range of transfer runs. For example,
      `"2017-05-30T00:00:00+00:00"`. The end_time must not be in the future.
      Creates transfer runs where run_time is in the range between start_time
      (inclusive) and end_time (exclusive).
    startTime: Start time of the range of transfer runs. For example,
      `"2017-05-25T00:00:00+00:00"`. The start_time must be strictly less than
      the end_time. Creates transfer runs where run_time is in the range
      between start_time (inclusive) and end_time (exclusive).
  """

  endTime = _messages.StringField(1)
  startTime = _messages.StringField(2)


class TransferConfig(_messages.Message):
  r"""Represents a data transfer configuration. A transfer configuration
  contains all metadata needed to perform a data transfer. For example,
  `destination_dataset_id` specifies where data should be stored. When a new
  transfer configuration is created, the specified `destination_dataset_id` is
  created when needed and shared with the appropriate data source service
  account.

  Enums:
    StateValueValuesEnum: Output only. State of the most recently updated
      transfer run.

  Messages:
    ParamsValue: Parameters specific to each data source. For more information
      see the bq tab in the 'Setting up a data transfer' section for each data
      source. For example the parameters for Cloud Storage transfers are
      listed here: https://cloud.google.com/bigquery-transfer/docs/cloud-
      storage-transfer#bq

  Fields:
    dataRefreshWindowDays: The number of days to look back to automatically
      refresh the data. For example, if `data_refresh_window_days = 10`, then
      every day BigQuery reingests data for [today-10, today-1], rather than
      ingesting data for just [today-1]. Only valid if the data source
      supports the feature. Set the value to 0 to use the default value.
    dataSourceId: Data source ID. This cannot be changed once data transfer is
      created. The full list of available data source IDs can be returned
      through an API call: https://cloud.google.com/bigquery-transfer/docs/ref
      erence/datatransfer/rest/v1/projects.locations.dataSources/list
    datasetRegion: Output only. Region in which BigQuery dataset is located.
    destinationDatasetId: The BigQuery target dataset id.
    disabled: Is this config disabled. When set to true, no runs are scheduled
      for a given transfer.
    displayName: User specified display name for the data transfer.
    emailPreferences: Email notifications will be sent according to these
      preferences to the email address of the user who owns this transfer
      config.
    name: The resource name of the transfer config. Transfer config names have
      the form
      `projects/{project_id}/locations/{region}/transferConfigs/{config_id}`.
      Where `config_id` is usually a uuid, even though it is not guaranteed or
      required. The name is ignored when creating a transfer config.
    nextRunTime: Output only. Next time when data transfer will run.
    notificationPubsubTopic: Pub/Sub topic where notifications will be sent
      after transfer runs associated with this transfer config finish. The
      format for specifying a pubsub topic is:
      `projects/{project}/topics/{topic}`
    ownerInfo: Output only. Information about the user whose credentials are
      used to transfer data. Populated only for `transferConfigs.get`
      requests. In case the user information is not available, this field will
      not be populated.
    params: Parameters specific to each data source. For more information see
      the bq tab in the 'Setting up a data transfer' section for each data
      source. For example the parameters for Cloud Storage transfers are
      listed here: https://cloud.google.com/bigquery-transfer/docs/cloud-
      storage-transfer#bq
    schedule: Data transfer schedule. If the data source does not support a
      custom schedule, this should be empty. If it is empty, the default value
      for the data source will be used. The specified times are in UTC.
      Examples of valid format: `1st,3rd monday of month 15:30`, `every
      wed,fri of jan,jun 13:15`, and `first sunday of quarter 00:00`. See more
      explanation about the format here:
      https://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-
      with-cron-yaml#the_schedule_format NOTE: The minimum interval time
      between recurring transfers depends on the data source; refer to the
      documentation for your data source.
    scheduleOptions: Options customizing the data transfer schedule.
    state: Output only. State of the most recently updated transfer run.
    updateTime: Output only. Data transfer modification time. Ignored by
      server on input.
    userId: Deprecated. Unique ID of the user on whose behalf transfer is
      done.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. State of the most recently updated transfer run.

    Values:
      TRANSFER_STATE_UNSPECIFIED: State placeholder (0).
      PENDING: Data transfer is scheduled and is waiting to be picked up by
        data transfer backend (2).
      RUNNING: Data transfer is in progress (3).
      SUCCEEDED: Data transfer completed successfully (4).
      FAILED: Data transfer failed (5).
      CANCELLED: Data transfer is cancelled (6).
    """
    TRANSFER_STATE_UNSPECIFIED = 0
    PENDING = 1
    RUNNING = 2
    SUCCEEDED = 3
    FAILED = 4
    CANCELLED = 5

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ParamsValue(_messages.Message):
    r"""Parameters specific to each data source. For more information see the
    bq tab in the 'Setting up a data transfer' section for each data source.
    For example the parameters for Cloud Storage transfers are listed here:
    https://cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq

    Messages:
      AdditionalProperty: An additional property for a ParamsValue object.

    Fields:
      additionalProperties: Properties of the object.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ParamsValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  dataRefreshWindowDays = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  dataSourceId = _messages.StringField(2)
  datasetRegion = _messages.StringField(3)
  destinationDatasetId = _messages.StringField(4)
  disabled = _messages.BooleanField(5)
  displayName = _messages.StringField(6)
  emailPreferences = _messages.MessageField('EmailPreferences', 7)
  name = _messages.StringField(8)
  nextRunTime = _messages.StringField(9)
  notificationPubsubTopic = _messages.StringField(10)
  ownerInfo = _messages.MessageField('UserInfo', 11)
  params = _messages.MessageField('ParamsValue', 12)
  schedule = _messages.StringField(13)
  scheduleOptions = _messages.MessageField('ScheduleOptions', 14)
  state = _messages.EnumField('StateValueValuesEnum', 15)
  updateTime = _messages.StringField(16)
  userId = _messages.IntegerField(17)


class TransferMessage(_messages.Message):
  r"""Represents a user facing message for a particular data transfer run.

  Enums:
    SeverityValueValuesEnum: Message severity.

  Fields:
    messageText: Message text.
    messageTime: Time when message was logged.
    severity: Message severity.
  """

  class SeverityValueValuesEnum(_messages.Enum):
    r"""Message severity.

    Values:
      MESSAGE_SEVERITY_UNSPECIFIED: No severity specified.
      INFO: Informational message.
      WARNING: Warning message.
      ERROR: Error message.
    """
    MESSAGE_SEVERITY_UNSPECIFIED = 0
    INFO = 1
    WARNING = 2
    ERROR = 3

  messageText = _messages.StringField(1)
  messageTime = _messages.StringField(2)
  severity = _messages.EnumField('SeverityValueValuesEnum', 3)


class TransferRun(_messages.Message):
  r"""Represents a data transfer run.

  Enums:
    StateValueValuesEnum: Data transfer run state. Ignored for input requests.

  Messages:
    ParamsValue: Output only. Parameters specific to each data source. For
      more information see the bq tab in the 'Setting up a data transfer'
      section for each data source. For example the parameters for Cloud
      Storage transfers are listed here: https://cloud.google.com/bigquery-
      transfer/docs/cloud-storage-transfer#bq

  Fields:
    dataSourceId: Output only. Data source id.
    destinationDatasetId: Output only. The BigQuery target dataset id.
    emailPreferences: Output only. Email notifications will be sent according
      to these preferences to the email address of the user who owns the
      transfer config this run was derived from.
    endTime: Output only. Time when transfer run ended. Parameter ignored by
      server for input requests.
    errorStatus: Status of the transfer run.
    name: The resource name of the transfer run. Transfer run names have the
      form `projects/{project_id}/locations/{location}/transferConfigs/{config
      _id}/runs/{run_id}`. The name is ignored when creating a transfer run.
    notificationPubsubTopic: Output only. Pub/Sub topic where a notification
      will be sent after this transfer run finishes. The format for specifying
      a pubsub topic is: `projects/{project}/topics/{topic}`
    params: Output only. Parameters specific to each data source. For more
      information see the bq tab in the 'Setting up a data transfer' section
      for each data source. For example the parameters for Cloud Storage
      transfers are listed here: https://cloud.google.com/bigquery-
      transfer/docs/cloud-storage-transfer#bq
    runTime: For batch transfer runs, specifies the date and time of the data
      should be ingested.
    schedule: Output only. Describes the schedule of this transfer run if it
      was created as part of a regular schedule. For batch transfer runs that
      are scheduled manually, this is empty. NOTE: the system might choose to
      delay the schedule depending on the current load, so `schedule_time`
      doesn't always match this.
    scheduleTime: Minimum time after which a transfer run can be started.
    startTime: Output only. Time when transfer run was started. Parameter
      ignored by server for input requests.
    state: Data transfer run state. Ignored for input requests.
    updateTime: Output only. Last time the data transfer run state was
      updated.
    userId: Deprecated. Unique ID of the user on whose behalf transfer is
      done.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Data transfer run state. Ignored for input requests.

    Values:
      TRANSFER_STATE_UNSPECIFIED: State placeholder (0).
      PENDING: Data transfer is scheduled and is waiting to be picked up by
        data transfer backend (2).
      RUNNING: Data transfer is in progress (3).
      SUCCEEDED: Data transfer completed successfully (4).
      FAILED: Data transfer failed (5).
      CANCELLED: Data transfer is cancelled (6).
    """
    TRANSFER_STATE_UNSPECIFIED = 0
    PENDING = 1
    RUNNING = 2
    SUCCEEDED = 3
    FAILED = 4
    CANCELLED = 5

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ParamsValue(_messages.Message):
    r"""Output only. Parameters specific to each data source. For more
    information see the bq tab in the 'Setting up a data transfer' section for
    each data source. For example the parameters for Cloud Storage transfers
    are listed here: https://cloud.google.com/bigquery-transfer/docs/cloud-
    storage-transfer#bq

    Messages:
      AdditionalProperty: An additional property for a ParamsValue object.

    Fields:
      additionalProperties: Properties of the object.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ParamsValue object.

      Fields:
        key: Name of the additional property.
        value: A extra_types.JsonValue attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('extra_types.JsonValue', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  dataSourceId = _messages.StringField(1)
  destinationDatasetId = _messages.StringField(2)
  emailPreferences = _messages.MessageField('EmailPreferences', 3)
  endTime = _messages.StringField(4)
  errorStatus = _messages.MessageField('Status', 5)
  name = _messages.StringField(6)
  notificationPubsubTopic = _messages.StringField(7)
  params = _messages.MessageField('ParamsValue', 8)
  runTime = _messages.StringField(9)
  schedule = _messages.StringField(10)
  scheduleTime = _messages.StringField(11)
  startTime = _messages.StringField(12)
  state = _messages.EnumField('StateValueValuesEnum', 13)
  updateTime = _messages.StringField(14)
  userId = _messages.IntegerField(15)


class UserInfo(_messages.Message):
  r"""Information about a user.

  Fields:
    email: E-mail address of the user.
  """

  email = _messages.StringField(1)


encoding.AddCustomJsonFieldMapping(
    StandardQueryParameters, 'f__xgafv', '$.xgafv')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_1', '1')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_2', '2')
